<?php

use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;

class GenerateBillCommand extends Command {

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'generate:bill';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Command to generate monthly rental bill on first date of month';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct() {
	parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return mixed
     */
    public function fire() {

	$operation = 'Generate rental bill for ' . date('M / Y');
	$errorMessage = '';
	$status = 'error';

	// Begin transaction, then rollback with error message if failed
	DB::beginTransaction();

	try {
	    // get date and convert to Y-m-d format
	    $date = date('Y-m') . '-01';

	    // search bill if already generated for that date. Later will check for not generate twice
	    $existBill = Bill::where('issue_date', 'LIKE', $date . '%')->lists('tenant_id');

	    // get tenants id to generate bills
	    $tenants = Tenant::select('tenants.id', 'rental_rate')
		    ->join('properties', 'properties.id', '=', 'tenants.property_id');

	    if (count($existBill)) {
		$tenants = $tenants->whereNotIn('tenants.id', $existBill);
	    }

	    $tenants = $tenants->get();

	    $lastId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

	    $i = $lastId;
	    // create bills
	    foreach ($tenants as $tenant) {

		$locationCode = Tenant::join('properties', 'properties.id', '=', 'tenants.property_id')
			->join('locations', 'locations.id', '=', 'properties.location_id')
			->pluck('location_code');

		$bill = new Bill;
		$bill->bill_amount = $tenant->rental_rate;
		$bill->amount_due = $tenant->rental_rate;
		$bill->bill_no = $locationCode . '-' . (1000000 + $i);
		$bill->created_by = 1; // admin
		$bill->bill_type_id = 1; // rental
		$bill->issue_date = $date . ' 00:00:00';
		$bill->tenant_id = $tenant->id;
		$bill->save();

		$i++;
	    }
	    
	    $totalGenerated = $i - $lastId;

	    DB::commit();
	    $status = 'success';
	} catch (Exception $e) {
	    DB::rollback();
	    $errorMessage = $e->getMessage();
	}

	// insert logs
	$cronlog = new CronLog;
	$cronlog->description = $operation;
	$cronlog->status = $status;
	$cronlog->error_message = $errorMessage;
	$cronlog->save();
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments() {
	return array(
	    array('example', InputArgument::OPTIONAL, 'An example argument.'),
	);
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions() {
	return array(
	    array('example', null, InputOption::VALUE_OPTIONAL, 'An example option.', null),
	);
    }

}
