<?php
class ApplicantController extends \BaseController
{
    
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index() {
        $data = array();
        // create location
        $locations = array(
                'Select Location',
                'Johor',
                'Kedah',
                'Kelantan',
                'Kuala Lumpur',
                'Melaka',
                'Negeri Sembilan',
                'Pahang',
                'Perlis',
                'Pulau Pinang',
                'Putrajaya',
                'Sabah',
                'selangor',
                'Serawak',
                'Terengganu',
            );


        $data['locations'] = $locations;
        $applicants = Applicant::select('applicants.id', 'ic_no', 'applicants.updated_at', 'name', 'application_status', 'interview_date', 'applicant_name', 'race', 'nationality')
        ->join('users', 'users.id', '=', 'applicants.created_by');

        $applicants = $applicants->where('applicants.location_id', Session::get('project')->location_id);
        
        if (Input::has('salfr') && Input::has('salto')) {
            if (Input::get('salfr') > 0 && Input::get('salto') > 0)
                $applicants = $applicants->whereBetween('salary', array(Input::get('salfr'), Input::get('salto')));
        }
        else if (Input::has('salfr')) {
            if (Input::get('salfr') > 0)
                $applicants = $applicants->where('salary', '>=', Input::get('salfr'));
        }
        else if (Input::has('salto')) {
            if (Input::get('salto') > 0)
                $applicants = $applicants->where('salary', '<=', Input::get('salto'));
        }

        if (Input::has('loc')) {
            if (Input::get('loc') != 0) {
                $location = $locations[Input::get('loc')];
                $applicants = $applicants->where('mailing_address', 'LIKE', '%' . $location . '%');
            }
        }

        $applicants = $applicants->where('applicants.status', 'enable')
        ->paginate(20);
        
        // pagination links and text
        $data['paginationLinks'] = $applicants->appends(Input::except('page'))->links();
        $data['paginationText'] = 'Showing ' . $applicants->getFrom() . ' - ' . $applicants->getTo() . ' of ' . $applicants->getTotal();
        
        $data['applicants'] = $applicants;
        $data['availableUnitsOptions'] = Property::getAvailableUnitOptions();
        


        $data['scripts'] = array('applicant-status-form.js', 'select-unit.js');
        
        return View::make('applicant.list', $data);
    }
    
    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create() {
        $data = array();
        $data['scripts'] = array('dynamic-form.js');
        return View::make('applicant.form', $data);
    }
    
    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store() {
        
        // validate post fields
        $rules = array(
            'ic_no' => 'required|numeric|unique:applicants|unique:tenants|unique:applicant_relatives|unique:applicant_spouses', 
            'applicant_name' => 'required|unique:applicants', 
            'gender' => 'required', 
            'marital_status' => 'required', 
            'nationality' => 'required', 
            'mailing_address' => 'required', 
            'email' => 'email|unique:applicants', 
            'race' => 'required', 
            'mobile' => 'required|numeric|unique:applicants', 
            'phone' => 'numeric', 'salary' => 'numeric', 'phone' => 'numeric', 'company_phone' => 'numeric', 'spouse_ic_no' => 'numeric', 'spouse_email' => 'email', 'spouse_mobile' => 'numeric', 'phone' => 'numeric', 'spouse_salary' => 'numeric', 'spouse_company_phone' => 'numeric',);
        
        $validator = Validator::make(Input::all(), $rules);
        
        // process the add
        if ($validator->fails()) {
            $inputs = Input::all();
            unset($inputs['relative_name']);
            unset($inputs['relative_ic_no']);
            unset($inputs['relationship']);
            unset($inputs['relative_job']);
            unset($inputs['relative_salary']);

            return Redirect::route('applicant.create')->withErrors($validator)->withInput($inputs);
        } 
        else {
            
            DB::transaction(function () {
                
                // get applicant
                $applicant_name = Input::get('applicant_name');
                $ic_no = Input::get('ic_no');
                $passport_no = Input::get('passport_no');
                $gender = Input::get('gender');
                $marital_status = Input::get('marital_status');
                $marital_status_text = Input::get('marital_status_text');
                $nationality = Input::get('nationality');
                $mailing_address = Input::get('mailing_address');
                $race = Input::get('race');
                $race_text = Input::get('race_text');
                $mobile = Input::get('mobile');
                $phone = Input::get('phone');
                $email = Input::get('email');
                $company_name = Input::get('company_name');
                $salary = Input::get('salary');
                $job = Input::get('job');
                $company_phone = Input::get('company_phone');
                
                // get spouse info
                $spouse_name = Input::get('spouse_name');
                $spouse_ic_no = Input::get('spouse_ic_no');
                $spouse_passport_no = Input::get('spouse_passport_no');
                $spouse_nationality = Input::get('spouse_nationality');
                $spouse_mobile = Input::get('spouse_mobile');
                $spouse_email = Input::get('spouse_email');
                $spouse_company_name = Input::get('spouse_company_name');
                $spouse_salary = Input::get('spouse_salary');
                $spouse_job = Input::get('spouse_job');
                $spouse_company_phone = Input::get('spouse_company_phone');
                
                // transportation info
                $transportation_name = Input::get('transportation_name');
                $plat_no = Input::get('plat_no');
                
                //  create new applicant with inputs
                $applicant = new Applicant;
                $applicant->location_id = Session::get('project')->location_id;
                $applicant->applicant_name = $applicant_name;
                $applicant->ic_no = $ic_no;
                $applicant->passport_no = $passport_no;
                $applicant->gender = $gender;
                
                if ($marital_status == 'others') {
                    $applicant->marital_status = $marital_status_text;
                } 
                else {
                    $applicant->marital_status = $marital_status;
                }
                
                $applicant->nationality = $nationality;
                $applicant->mailing_address = $mailing_address;
                
                if ($race == 'others') {
                    $applicant->race = $race_text;
                } 
                else {
                    $applicant->race = $race;
                }
                
                $applicant->mobile = $mobile;
                $applicant->phone = $phone;
                $applicant->email = $email;
                $applicant->company_name = $company_name;
                $applicant->job = $job;
                $applicant->company_phone = $company_phone;
                $applicant->salary = $salary;
                $applicant->application_status = 'submitted';
                 // submitted , reviewed, intervied, failed, passed
                $applicant->created_by = Auth::id();
                $applicant->save();
                
                if (strlen($spouse_name)) {
                    $spouse = new ApplicantSpouse;
                    $spouse->spouse_name = $spouse_name;
                    $spouse->ic_no = $spouse_ic_no;
                    $spouse->passport_no = $spouse_passport_no;
                    $spouse->email = $spouse_email;
                    $spouse->nationality = $spouse_nationality;
                    $spouse->mobile = $spouse_mobile;
                    $spouse->company_name = $spouse_company_name;
                    $spouse->company_phone = $spouse_company_phone;
                    $spouse->salary = $spouse_salary;
                    $spouse->job = $spouse_job;
                    $spouse->applicant_id = $applicant->id;
                    $spouse->save();
                }
                
                if (strlen($transportation_name)) {
                    $transport = new ApplicantTransport;
                    $transport->transport_name = $transportation_name;
                    $transport->plat_no = $plat_no;
                    $transport->applicant_id = $applicant->id;
                    $transport->save();
                }
                
                $property_status = Input::get('property_status');
                $property_type = Input::get('property_type');
                $line1 = Input::get('line1');
                $line2 = Input::get('line2');
                $city = Input::get('city');
                $state = Input::get('state');
                $postcode = Input::get('postcode');
                $country = Input::get('country');
                
                if ($property_status != '') {
                    $property = new ApplicantProperty;
                    $property->property_status = $property_status;
                    $property->property_type = $property_type;
                    $property->line1 = $line1;
                    $property->line2 = $line2;
                    $property->city = $city;
                    $property->state = $state;
                    $property->postcode = $postcode;
                    $property->country = $country;
                    $property->applicant_id = $applicant->id;
                    $property->save();
                }
                
                $relative_name = Input::get('relative_name');
                $relative_ic_no = Input::get('relative_ic_no');
                $relative_job = Input::get('relative_job');
                $relative_salary = Input::get('relative_salary');
                $relationship = Input::get('relationship');
                
                for ($i = 0; $i < count($relative_name); $i++) {
                    if (strlen($relative_name[$i])) {
                        
                        $relative = new ApplicantRelative;
                        $relative->relative_name = $relative_name[$i];
                        $relative->relationship = $relationship[$i];
                        $relative->job = $relative_job[$i];
                        $relative->ic_no = $relative_ic_no[$i];
                        $relative->salary = $relative_salary[$i];
                        $relative->applicant_id = $applicant->id;
                        $relative->save();
                    }
                }
            });
            
            // redirect to user routing with message
            return Redirect::to('applicant')->with('message', 'Applicant has been successfully registered.');
        }
    }
    
    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id) {
        $data = array();
        
        $data['applicant'] = Applicant::find($id);
        $data['spouse'] = ApplicantSpouse::where('applicant_id', $id)->first();
        $data['property'] = ApplicantProperty::where('applicant_id', $id)->first();
        $data['relatives'] = ApplicantRelative::where('applicant_id', $id)->get();
        $data['transport'] = ApplicantTransport::where('applicant_id', $id)->first();
        
        return View::make('applicant.details', $data);
    }
    
    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id) {
        $data = array();
        $applicant = Applicant::find($id);
        $spouse = ApplicantSpouse::where('applicant_id', $id)->first();
        $property = ApplicantProperty::where('applicant_id', $id)->first();
        $data['relatives'] = ApplicantRelative::where('applicant_id', $id)->get();
        $transport = ApplicantTransport::where('applicant_id', $id)->first();
        $property = ApplicantProperty::where('applicant_id', $id)->first();
        
        if (isset($spouse)) {
            $applicant->spouse_name = $spouse->spouse_name;
            $applicant->spouse_ic_no = $spouse->ic_no;
            $applicant->spouse_passport = $spouse->passport;
            $applicant->spouse_nationality = $spouse->nationality;
            $applicant->spouse_mobile = $spouse->mobile;
            $applicant->spouse_email = $spouse->email;
            $applicant->spouse_job = $spouse->job;
            $applicant->spouse_salary = $spouse->salary == 0 ? '' : $spouse->salary;
            $applicant->spouse_company_phone = $spouse->company_phone;
        }
        
        if (isset($transport)) {
            if (strlen($transport->transport_name)) {
                $applicant->transportation_name = $transport->transport_name;
                $applicant->plat_no = $transport->plat_no;
            }
        }
        
        if (isset($property)) {
            $applicant->property_type = $property->property_type;
            $applicant->property_status = $property->property_status;
            $applicant->line1 = $property->line1;
            $applicant->line2 = $property->line2;
            $applicant->state = $property->state;
            $applicant->city = $property->city;
            $applicant->postcode = $property->postcode;
            $applicant->country = $property->country;
        }
        
        if (isset($relatives)) {
            $i = 0;
            foreach ($relatives as $relative) {
                $relative_name = 'relative_name_' . $i;
                $relative_ic_no = 'relative_ic_no_' . $i;
                $relative_job = 'relative_job_' . $i;
                $relative_salary = 'relative_salary_' . $i;
                $relationship = 'relationship_' . $i;
                $applicant->$relative_name = $relative->relative_name;
                $applicant->$relative_ic_no = $relative->ic_no;
                $applicant->$relative_salary = $relative->salary;
                $applicant->$relative_job = $relative->job;
                $applicant->$relationship = $relative->relationship;
                
                $i++;
            }
        }
        
        $data['applicant'] = $applicant;
        $data['scripts'] = array('dynamic-form.js');
        
        return View::make('applicant.form', $data);
    }
    
    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id) {
        
        // validate post fields
        $rules = array('ic_no' => 'required|numeric|unique:applicants,ic_no,' . $id .',|unique:tenants,ic_no,' . $id, 
            'applicant_name' => 'required|unique:applicants,applicant_name,' . $id, 
            'gender' => 'required', 'marital_status' => 'required', 'nationality' => 'required', 'mailing_address' => 'required', 'email' => 'email|unique:applicants,email,' . $id, 'race' => 'required', 'mobile' => 'required|numeric|unique:applicants,mobile,' . $id, 'phone' => 'numeric', 'salary' => 'numeric', 'phone' => 'numeric', 'company_phone' => 'numeric', 'spouse_ic_no' => 'numeric', 'spouse_email' => 'email', 'spouse_mobile' => 'numeric', 'phone' => 'numeric', 'spouse_salary' => 'numeric', 'spouse_company_phone' => 'numeric',);
        
        $validator = Validator::make(Input::all(), $rules);
        
        // process the add
        if ($validator->fails()) {
            return Redirect::route('applicant.edit', $id)->withErrors($validator)->withInput(Input::all());
        } 
        else {
            
            DB::transaction(function () use ($id) {
                
                // get applicant
                $applicant_name = Input::get('applicant_name');
                $ic_no = Input::get('ic_no');
                $passport_no = Input::get('passport_no');
                $gender = Input::get('gender');
                $marital_status = Input::get('marital_status');
                $marital_status_text = Input::get('marital_status_text');
                $nationality = Input::get('nationality');
                $mailing_address = Input::get('mailing_address');
                $race = Input::get('race');
                $race_text = Input::get('race_text');
                $mobile = Input::get('mobile');
                $phone = Input::get('phone');
                $email = Input::get('email');
                $company_name = Input::get('company_name');
                $salary = Input::get('salary');
                $job = Input::get('job');
                $company_phone = Input::get('company_phone');
                
                // get spouse info
                $spouse_name = Input::get('spouse_name');
                $spouse_ic_no = Input::get('spouse_ic_no');
                $spouse_passport_no = Input::get('spouse_passport_no');
                $spouse_nationality = Input::get('spouse_nationality');
                $spouse_mobile = Input::get('spouse_mobile');
                $spouse_email = Input::get('spouse_email');
                $spouse_company_name = Input::get('spouse_company_name');
                $spouse_salary = Input::get('spouse_salary');
                $spouse_job = Input::get('spouse_job');
                $spouse_company_phone = Input::get('spouse_company_phone');
                
                // transportation info
                $transportation_name = Input::get('transportation_name');
                $plat_no = Input::get('plat_no');
                
                //  create new applicant with inputs
                $applicant = Applicant::find($id);
                $applicant->applicant_name = $applicant_name;
                $applicant->ic_no = $ic_no;
                $applicant->passport_no = $passport_no;
                $applicant->gender = $gender;
                
                if ($marital_status == 'others') {
                    $applicant->marital_status = $marital_status_text;
                } 
                else {
                    $applicant->marital_status = $marital_status;
                }
                
                $applicant->nationality = $nationality;
                $applicant->mailing_address = $mailing_address;
                
                if ($race == 'others') {
                    $applicant->race = $race_text;
                } 
                else {
                    $applicant->race = $race;
                }
                
                $applicant->mobile = $mobile;
                $applicant->phone = $phone;
                $applicant->email = $email;
                $applicant->company_name = $company_name;
                $applicant->job = $job;
                $applicant->company_phone = $company_phone;
                $applicant->salary = $salary;
                $applicant->application_status = 'submitted';
                 // submitted , reviewed, intervied, failed, passed
                $applicant->created_by = Auth::id();
                $applicant->save();
                
                $spouse = ApplicantSpouse::where('applicant_id', $id)->first();
                $property = ApplicantProperty::where('applicant_id', $id)->first();
                $relatives = ApplicantRelative::where('applicant_id', $id)->get();
                $transport = ApplicantTransport::where('applicant_id', $id)->first();
                $property = ApplicantProperty::where('applicant_id', $id)->first();
                
                if (strlen($spouse_name)) {
                    $spouse = isset($spouse) ? $spouse : new ApplicantSpouse;
                    $spouse->spouse_name = $spouse_name;
                    $spouse->ic_no = $spouse_ic_no;
                    $spouse->passport_no = $spouse_passport_no;
                    $spouse->email = $spouse_email;
                    $spouse->nationality = $spouse_nationality;
                    $spouse->mobile = $spouse_mobile;
                    $spouse->company_name = $spouse_company_name;
                    $spouse->company_phone = $spouse_company_phone;
                    $spouse->salary = $spouse_salary;
                    $spouse->job = $spouse_job;
                    $spouse->applicant_id = $applicant->id;
                    $spouse->save();
                }
                
                $transport = isset($transport) ? $transport : new ApplicantTransport;
                $transport->transport_name = $transportation_name;
                $transport->plat_no = $plat_no;
                $transport->applicant_id = $applicant->id;
                $transport->save();
                
                $property_status = Input::get('property_status');
                $property_type = Input::get('property_type');
                $line1 = Input::get('line1');
                $line2 = Input::get('line2');
                $city = Input::get('city');
                $state = Input::get('state');
                $postcode = Input::get('postcode');
                $country = Input::get('country');
                
                if ($property_status != '') {
                    $property = isset($property) ? $property : new ApplicantProperty;
                    $property->property_status = $property_status;
                    $property->property_type = $property_type;
                    $property->line1 = $line1;
                    $property->line2 = $line2;
                    $property->city = $city;
                    $property->state = $state;
                    $property->postcode = $postcode;
                    $property->country = $country;
                    $property->applicant_id = $applicant->id;
                    $property->save();
                }
                
                // clear child data before insert new (instead of update each)
                foreach ($relatives as $relative) {
                    $relative->delete();
                }
                
                $relative_name = Input::get('relative_name');
                $relative_ic_no = Input::get('relative_ic_no');
                $relative_job = Input::get('relative_job');
                $relative_salary = Input::get('relative_salary');
                $relationship = Input::get('relationship');
                
                for ($i = 0; $i < count($relative_name); $i++) {
                    if (strlen($relative_name[$i])) {
                        
                        $relative = new ApplicantRelative;
                        $relative->relative_name = $relative_name[$i];
                        $relative->relationship = $relationship[$i];
                        $relative->job = $relative_job[$i];
                        $relative->ic_no = $relative_ic_no[$i];
                        $relative->salary = $relative_salary[$i];
                        $relative->applicant_id = $applicant->id;
                        $relative->save();
                    }
                }
            });
            
            // redirect to user routing with message
            return Redirect::to('applicant')->with('message', 'Applicant has been successfully updated.');
        }
    }
    
    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id) {
        
        //
        
    }
    
    public function changeApplicantStatus() {
        $applicantId = Input::get('applicant_id');
        $status = Input::get('status');
        $interviewDate = Input::get('interview_date');
        
        $applicant = Applicant::find($applicantId);
        $applicant->application_status = $status;
        if ($status == 'interview') {
            $applicant->interview_date = date('Y-m-d', strtotime($interviewDate));
        } 
        else {
            $applicant->interview_date = '0000-00-00 00:00:00';
        }
        $applicant->save();
        
        // changed status to moved as tenant
        if ($status === 'moved') {
            $transStatus = '';
            DB::transaction(function () use (&$transStatus, $applicant) {
                
                $propertyId = Input::get('property_id');
                $property = Property::find($propertyId);
                
                if ($property) {
                    
                    // set property vacancy to unvailable
                    $property->vacancy = 'unavailable';
                    $property->save();
                    
                    //  create new tenant with inputs
                    $tenant = new Tenant;
                    $tenant->tenant_name = $applicant->applicant_name;
                    $tenant->ic_no = $applicant->ic_no;
                    $tenant->passport_no = $applicant->passport_no;
                    $tenant->gender = $applicant->gender;
                    $tenant->marital_status = $applicant->marital_status;
                    $tenant->nationality = $applicant->nationality;
                    $tenant->mailing_address = $applicant->mailing_address;
                    $tenant->race = $applicant->race;
                    $tenant->mobile = $applicant->mobile;
                    $tenant->phone = $applicant->phone;
                    $tenant->email = $applicant->email;
                    $tenant->company_name = $applicant->company_name;
                    $tenant->company_phone = $applicant->company_phone;
                    $tenant->start_date = date('Y-m-d H:i:s');
                    $tenant->property_id = $property->id;
                    $tenant->created_by = Auth::id();
                    
                    $tenant->save();
                    
                    // get last id in bill table
                    $lastId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;
                    
                    // create current month rental bill
                    $bill = new Bill;
                    $bill->bill_amount = $property->rental_rate;
                    $bill->amount_due = $property->rental_rate;
                    $bill->bill_no = Session::get('project')->location_code . '-' . (1000000 + $lastId);
                    $bill->created_by = Auth::id();
                    $bill->bill_type_id = 1;
                     // rental
                    $bill->issue_date = date('Y-m') . '-01 00:00:00';
                    $bill->tenant_id = $tenant->id;
                    $bill->save();
                    
                    $transStatus = 'success';
                    
                    if ($tenant->email != '') {
                        
                        // send email
                        $mail['name'] = $tenant->tenant_name;
                        $mail['email'] = $tenant->email;
                        $mail['subject'] = 'PHSSB: Pendaftaran Sebagai Penyewa';
                        
                        $data['name'] = $tenant->tenant_name;
                        
                        Mail::send('emails.welcome', $data, function ($message) use ($mail) {
                            $message->to($mail['email'], $mail['name'])->subject($mail['subject']);
                        });
                    }
                } 
                else {
                    $transStatus = 'unit invalid';
                }
            });
            
            if ($transStatus === 'success') {
                
                // redirect to user routing with message
                return Redirect::to('applicant/create')->with('message', 'Applicant has been successfully registered as Tenant.');
            } 
            else if ($transStatus == 'unit invalid') {
                return Redirect::to('tenant/create')->with('error', 'Registration as Tenant cannot be completed. The unit no is not valid or not available.')->withInput(Input::all());
            }
        }
        
        return Redirect::back()->with('message', 'Application status has been successfully updated');
    }
}
