<?php

class AuthController extends \BaseController {

    public function index() {

	$data = array();
	$data['title'] = 'Login';

	return View::make('login.index', $data);
    }

    public function submitLogin() {
	// validate the info, create rules for the inputs
	$rules = array(
	    'username' => 'required',
	    'password' => 'required'
	);

	// run the validation rules on the inputs from the form
	$validator = Validator::make(Input::all(), $rules);

	$errorMessage = 'Invalid username or password';
	// if the validator fails, redirect back to the form
	if ($validator->fails()) {
	    return Redirect::to('login')->with('error', $errorMessage); // send back all errors to the login form
	} else {
	    // create our user data for the authentication
	    $userdata = array(
		'username' => Input::get('username'),
		'password' => Input::get('password')
	    );

	    // attempt to do the login
	    if (Auth::attempt($userdata)) {
		if (Auth::user()->status === 'disable') {
		    return Redirect::to('login')->with('error', 'Your account is disabled');
		}

		$project = Location::select('locations.id as location_id', 'location_name', 'projects.id as project_id', 'project_name', 'location_code', 'maximum_notice', 'has_water_bill')
			->join('projects', 'projects.id', '=', 'locations.project_id')
			->where('locations.id', Auth::user()->location_id)
			->first();

		Session::put('project', $project);

		if (Auth::user()->type != 'admin') {
		    $selectedLocation = array();
		    $selectedLocation = ExtraLocation::where('user_id', Auth::id())
			    ->lists('location_id');
		    array_push($selectedLocation, Auth::user()->location_id);

		    $accessibleLocations = Location::whereIn('id', $selectedLocation)->get();
		    Session::put('locations', $accessibleLocations);
		}

		// validation successful!
		return Redirect::to('/');
	    } else {

		// validation not successful, send back to form	
		return Redirect::to('login')->with('error', $errorMessage);
	    }
	}
    }

    public function switchAdminLocation($id) {
	$project = Location::select('locations.id as location_id', 'location_name', 'projects.id as project_id', 'project_name', 'location_code', 'maximum_notice', 'has_water_bill')
		->join('projects', 'projects.id', '=', 'locations.project_id')
		->where('locations.id', $id)
		->first();

	Session::put('project', $project);

	return Redirect::to('dashboard')->with('message', 'You have been switched to ' . $project->project_name . ' - ' . $project->location_name);
    }

}
