<?php

class BillController extends \BaseController {

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index() {
	$data = array();

	$bills = Bill::select('bills.id', 'unit_no', 'tenant_name', 'issue_date', 'bill_type_name', 'bill_no', 'payment_status', 'bill_amount', 'bills.updated_at')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
		->join('properties', 'properties.id', '=', 'tenants.property_id')
		->orderBy('unit_no');
	
	if (Input::get('status') == 'paid' || !Input::has('status')) {
	    $bills = $bills->where('payment_status', 'paid');
	}
	else {
	    $bills = $bills->where('payment_status', 'unpaid');
	}
	
	if (Input::get('type') == 'rental' || !Input::has('type')) {
	    $bills = $bills->where('bill_type_name', 'Rental');
	}
	else if (Input::get('type') == 'water') {
	    $bills = $bills->where('bill_type_name', 'Water');
	}
	else if (Input::get('type') == 'other'){
	    $bills = $bills->whereNotIn('bill_type_name', array('Water', 'Rental'));
	}
	
	$bills = $bills->paginate(100);

	// pagination links and text
	$data['paginationLinks'] = $bills->appends(Input::except('page'))->links();
	$data['paginationText'] = 'Showing ' . $bills->getFrom() . ' - ' . $bills->getTo() . ' of ' . $bills->getTotal();

	$data['bills'] = $bills;
	$data['scripts'] = array('report-analysis.js');
	return View::make('bill.list', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create() {
	//
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store() {
	// get date and convert to Y-m-d format
	$monYear = Input::get('mon_year');
	$date = date('Y-m', strtotime($monYear)) . '-01';

	// search bill if already generated for that date. Later will check for not generate twice
	$existBill = Bill::where('issue_date', 'LIKE', $date . '%')->lists('tenant_id');

	// get tenants id to generate bills
	$tenants = Tenant::select('tenants.id', 'rental_rate', 'location_code')
		->join('properties', 'properties.id', '=', 'tenants.property_id')
		->join('locations', 'locations.id', '=', 'properties.location_id');

	if (count($existBill)) {
	    $tenants = $tenants->whereNotIn('tenants.id', $existBill);
	}

	$tenants = $tenants->get();

	$lastId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

	$i = $lastId;
	// create bills
	foreach ($tenants as $tenant) {
	    $bill = new Bill;
	    $bill->bill_amount = $tenant->rental_rate;
	    $bill->amount_due = $tenant->rental_rate;
	    $bill->bill_no = $tenant->location_code . '-' . (1000000 + $i);
	    $bill->created_by = 1; // admin
	    $bill->bill_type_id = 1; // rental
	    $bill->issue_date = $date . ' 00:00:00';
	    $bill->tenant_id = $tenant->id;
	    $bill->save();

	    $i++;
	}

	return Redirect::action('BillController@index')->with('message', 'Bills for ' . $monYear . ' have been successfully generated.');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id) {
	//
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id) {
	//
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id) {
	//
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id) {
	//
    }

    public function getNotice($option) {

	$data = array();
	$data['notice'] = $option;

	// get tenant with bill for this month status is unpaid
        // ain 20151203
	/*$tenants = Tenant::join('bills', 'bills.tenant_id', '=', 'tenants.id')
		->join('properties', 'properties.id', '=', 'tenants.property_id')
                ->where('tenants.status','<>','disable')
		->where('issue_date', 'LIKE', date('Y-m') . '%')
		->where('payment_status', '<>', 'paid')
		->where('location_id', Session::get('project')->location_id)
		->get();*/
	//ain 20160111
	$tenants = Tenant::join('bills', 'bills.tenant_id', '=', 'tenants.id')
		->join('properties', 'properties.id', '=', 'tenants.property_id')
		->join('locations', 'locations.id', '=', 'properties.location_id')
                ->where('tenants.status','<>','disable')
		->where('issue_date', 'LIKE', date('Y-m') . '%')
		->where('payment_status', '<>', 'paid')
		->where('location_id', Session::get('project')->location_id)
		->get();
	//end ain
	$data['tenants'] = $tenants;
	
	foreach ($tenants as $tenant) {
	    $notice = NoticeHistory::where('tenant_id', $tenant->tenant_id)
		    ->where('created_at', 'LIKE', date('Y-m') . '%')
		    ->where('notice_sequence', $option)
		    ->first();
	    
	    if (!$notice) {
		$noticeHistory = new NoticeHistory;
		$noticeHistory->notice_sequence = $option;
		$noticeHistory->tenant_id = $tenant->tenant_id;
		$noticeHistory->save();
	    }
	}
	return View::make('notice.notice', $data);
    }

    public function notPaidList() {
	$data = array();

         // ain 20151203
	$bills = Bill::select('unit_no', 'tenant_name', 'amount_due', 'bill_type_name')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
		->join('properties', 'properties.id', '=', 'tenants.property_id')
		->where('payment_status', '<>', 'paid')
                ->where('tenants.status','<>','disable')
		->whereIn('bill_type_id', array(1,2))
		->where('location_id', Session::get('project')->location_id)
		->orderBy('unit_no');

	if (Input::has('month')) {
	    $monYear = Input::get('month');
	    $date = date('Y-m', strtotime($monYear)) . '-01';
	    $bills = $bills->where('issue_date', 'LIKE', $date . '%');
	} else {
	    $bills = $bills->where('issue_date', 'LIKE', date('Y-m') . '%');
	}

	if (Input::has('format')) {

	    $data['monYear'] = date('m / Y');
	    if (Input::has('month')) {
		$monYear = Input::get('month');
		$data['monYear'] = date('m / Y', strtotime($monYear));
	    }
	    $data['bills'] = $bills->get();

	    return View::make('notice.print_notpaid', $data);
	} else {
	    $bills = $bills->paginate(100);

	    // pagination links and text
	    $data['paginationLinks'] = $bills->appends(Input::except('page'))->links();
	    $data['paginationText'] = 'Showing ' . $bills->getFrom() . ' - ' . $bills->getTo() . ' of ' . $bills->getTotal();

	    $data['bills'] = $bills;
	    $data['scripts'] = array('report-analysis.js');

	    return View::make('notice.notpaid', $data);
	}
    }

    public function filterNotPaidList() {
	// get date and convert to Y-m-d format
	$monYear = Input::get('mon_year');

	return Redirect::action('BillController@notPaidList', array('month' => $monYear));
    }

}
