<?php

class DashboardController extends \BaseController {

    /**
     * Display a dashboard.
     *
     * @return Response
     */
    public function index() {
    	$data = array();
    	$summary = $this->statistics();

    	$data['rentalPercentages'] = $summary['rentalPercentages'];
    	$data['waterPercentages'] = $summary['waterPercentages'];

    	$data['tenantsCount'] = Tenant::join('properties', 'properties.id', '=', 'tenants.property_id');
    	if (Session::get('project')->location_name != 'PHSSB') {
    		$data['tenantsCount'] = $data['tenantsCount']->where('properties.location_id', Session::get('project')->location_id);
    	}
    	$data['tenantsCount'] = $data['tenantsCount']->count();

		// this month section
    	$data['thisMonthPaymentCount'] = Payment::getThisMonthCollection()->count();

		// rental
    	$data['thisMonthRentalSum'] = Payment::getThisMonthCollection()
    	->where('bills.bill_type_id', '<>', 2)
    	->sum('payments.amount_paid');

    	$data['thisMonthRentalOutstandingSum'] = Payment::getThisMonthCollection()
    	->where('bills.issue_date', '<', date('Y-m-') . '01 00:00:00')
    	->where('bills.bill_type_id', '<>', 2)
    	->sum('payments.amount_paid');

		// water
    	$data['thisMonthWaterSum'] = Payment::getThisMonthCollection()
    	->where('bills.bill_type_id', 2)
    	->sum('payments.amount_paid');

    	$data['thisMonthWaterOutstandingSum'] = Payment::getThisMonthCollection()
    	->where('bills.issue_date', '<', date('Y-m-') . '01 00:00:00')
    	->where('bills.bill_type_id', 2)
    	->sum('payments.amount_paid');

    	$data['thisMonthTotalDeposit'] = Deposit::getThisMonthDeposit()->sum('total_deposit');
    	$data['thisMonthTotal'] = sprintf('%0.2f', (Payment::getThisMonthCollection()->whereIn('bill_type_id', array(1, 2))->sum('amount_paid') + $data['thisMonthTotalDeposit']));

		// today section
    	$today = date('Y-m-d');
    	$data['todayPaymentCount'] = Payment::join('bills', 'bills.id', '=', 'payments.bill_id')
    	->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id');
    	if (Session::get('project')->location_name != 'PHSSB') {
    		$data['todayPaymentCount'] = $data['todayPaymentCount']->where('properties.location_id', Session::get('project')->location_id);
    	}
    	$data['todayPaymentCount'] = $data['todayPaymentCount']
    	->where('payments.created_at', 'LIKE', $today . '%')
    	->count();

		// Rental
    	$todayRentalPaid = Payment::getTodayCollection()
    	->where('bill_type_id', '<>', 2)
    	->sum('amount_paid');
    	$data['todayRentalPaid'] = sprintf('%0.2f', $todayRentalPaid);
    	$data['todayRentalOutstandingCollections'] = Payment::getTodayOutstandingCollection()
    	->where('bill_type_id', '<>', 2)
    	->sum('amount_paid');

		// Water
    	$todayWaterPaid = Payment::getTodayCollection()
    	->where('bill_type_id', 2)
    	->sum('amount_paid');
    	$data['todayWaterPaid'] = sprintf('%0.2f', $todayWaterPaid);
    	$data['todayWaterOutstandingCollections'] = Payment::getTodayOutstandingCollection()
    	->where('bill_type_id', 2)
    	->sum('amount_paid');

    	$data['totalTodayCollection'] = $data['todayRentalOutstandingCollections'] + $data['todayRentalPaid'] + $data['todayWaterOutstandingCollections'] + $data['todayWaterPaid'];

    	$data['scripts'] = array('dashboard.js', 'check-receipt.js');

    	return View::make('dashboard.index', $data);
    }

    public function statistics() {

    	$rentalStatistics = array();
    	$waterStatistics = array();

    	$dates = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->orderBy('issue_date', 'DESC')
    	->where('issue_date', '<', date('Y-m-d H:i:s'))
		->where('bill_type_id', 1) // rental
		->distinct()
		->take(12)
		->lists('issue_date');

		$monthlyTenantsCount = array();


		foreach ($dates as $date) {
			$sumTenantRentalRate = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->where('issue_date', $date);

			if (Session::get('project')->location_name != 'PHSSB') {
				$sumTenantRentalRate = $sumTenantRentalRate->where('properties.location_id', Session::get('project')->location_id);
			}
	    	// get total tenant that have bill this month
			$total = $sumTenantRentalRate->where('bill_type_id', 1)->count();

	    	// get total amount if all tenants paid rental 
			$sumTenantRentalRate = $sumTenantRentalRate->where('bill_type_id', 1)
			->sum('tenants.rental_rate');

	    	// get total of paid amount
			$sumTenantPaidRental = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->where('issue_date', $date);

			if (Session::get('project')->location_name != 'PHSSB') {
				$sumTenantPaidRental = $sumTenantPaidRental->where('properties.location_id', Session::get('project')->location_id);
			}

			$sumTenantPaidRental = $sumTenantPaidRental->where('bill_type_id', 1)
			->where('payment_status', 'paid')
			->sum('tenants.rental_rate');

	    	// calulcate percentage based on total amount paid / total amount in rental rate
			$percent = $sumTenantPaidRental > 0 ? sprintf('%0.1f', $sumTenantPaidRental / $sumTenantRentalRate * 100) : 0;

			$stats = array('month' => date('M Y', strtotime($date)), 'percent' => $percent, 'amount' => (int)$sumTenantPaidRental);

			array_push($rentalStatistics, $stats);
			array_push($monthlyTenantsCount, $total);
		}

		$i = 0;
		// water statistics
		foreach ($dates as $date) {
			$paidCount = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
			->where('issue_date', $date);

			if (Session::get('project')->location_name != 'PHSSB') {
				$paidCount = $paidCount->join('properties', 'properties.id', '=', 'tenants.property_id')
				->where('properties.location_id', Session::get('project')->location_id);
			}

			$paidCount = $paidCount->where('bill_type_id', 2)
			->where('payment_status', 'paid')
			->count();

			$total = $monthlyTenantsCount[$i];

			$percent = $paidCount > 0 ? sprintf('%0.1f', $paidCount / $total * 100) : 0;

			$stats = array('month' => date('M Y', strtotime($date)), 'percent' => $percent);

			array_push($waterStatistics, $stats);
			$i++;
		}

		return array('rentalPercentages' => array_reverse($rentalStatistics), 'waterPercentages' => array_reverse($waterStatistics));
	}

	public function summary() {
		return Response::json($this->statistics());
	}

}
