<?php

class NoteController extends \BaseController {

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index() {
	$data = array();

	if (Input::has('edit')) {
	    $data['oldNote'] = Note::find(Input::get('edit'));
	}

	$propertyId = Input::get('property');
	$data['property'] = Property::find($propertyId);

	$data['notes'] = Note::select('notes.id', 'text', 'name', 'notes.created_at', 'notes.created_by')
		->join('users', 'users.id', '=', 'notes.created_by')
		->where('property_id', $propertyId)
		->where('notes.status', 'enable')
		->orderBy('created_at', 'DESC')
		->get();

	return View::make('note.list', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create() {
	//
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store() {
	$rules = array('text' => 'required');

	$validator = Validator::make(Input::all(), $rules);

	// process the add
	if ($validator->fails()) {
	    return Redirect::route('note.index')
			    ->withErrors($validator)
			    ->withInput(Input::all());
	} else {
	    $text = Input::get('text');
	    $propertyId = Input::get('property_id');

	    $notes = new Note;
	    $notes->text = $text;
	    $notes->created_by = Auth::id();
	    $notes->property_id = $propertyId;
	    $notes->save();

	    return Redirect::route('note.index', array('property' => $propertyId))->with('message', 'Note has been successfully created.');
	}
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id) {
	//
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id) {
	//
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id) {
	$rules = array('text' => 'required');

	$validator = Validator::make(Input::all(), $rules);

	// process the add
	if ($validator->fails()) {
	    return Redirect::route('note.index')
			    ->withErrors($validator)
			    ->withInput(Input::all());
	} else {
	    $text = Input::get('text');

	    $notes = Note::find($id);
	    $notes->text = $text;
	    $notes->created_by = Auth::id();
	    $notes->save();

	    return Redirect::action('NoteController@index', array('property' => $notes->property_id))->with('message', 'Note has been successfully updated.');
	}
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id) {
	$notes = Note::find($id);
	$notes->status = 'disable';
	$notes->save();
    }

}
