<?php

class PaymentController extends \BaseController {

	/**
	 * Display a listing of the resource.
	 *
	 * @return Response
	 */
	public function index() {
		$data = array();

		$id = Input::get('tenant') ? (int) Input::get('tenant') : '';

		$tenant = Tenant::select('tenants.id', 'unit_no', 'ic_no', 'tenant_name', 'passport_no', 'tenants.status', 'start_date', 'other_payment', 'mobile', 'property_type', 'rental_rate')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->where('tenants.id', $id)
			->first();

		$data['tenant'] = $tenant;

		$rentalRate = Tenant::join('properties', 'properties.id', '=', 'tenants.property_id')
			->where('tenants.id', $id)
			->pluck('rental_rate');

		$bills = Bill::select('bills.created_at', 'payment_status', 'bill_type_name as bill_type', 'amount_due')
			->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
			->where('tenant_id', $id)
			->get();

		if ($id != '') {
			$data['rentalRate'] = $rentalRate;
			$data['currentRental'] = Bill::getCurrentRentalBillByTenantId($id);
			$data['totalOutstandingRental'] = Bill::getTotalRentalOutstandingByTenantId($id);
			$data['currentWater'] = Bill::getCurrentWaterBillByTenantId($id);
			$data['totalOutstandingWater'] = Bill::getTotalWaterOutstandingByTenantId($id);

			$data['deposit'] = Deposit::where('tenant_id', $id)->first();

			if ($data['tenant']->other_payment == 1) {
				// if have payment such as MBPJ, LPHS etc
				$data['otherPayment'] = Bill::join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
					->whereNotIn('bill_type_id', array(1, 2))
					->where('tenant_id', $id)
					->first();
			}
		}

		$data['project'] = Location::find(Session::get('project')->location_id);
		$data['scripts'] = array('check-payment.js', 'date-mon-year.js', 'deposit.js');

		return View::make('payment.index', $data);
	}

	/**
	 * Show the form for creating a new resource.
	 *
	 * @return Response
	 */
	public function create() {
		//
	}

	/**
	 * Store a newly created resource in storage.
	 *
	 * @return Response
	 */
	public function store() {
		//
	}

	/**
	 * Display the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function show($id) {
		//
	}

	/**
	 * Show the form for editing the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function edit($id) {
		//
	}

	/**
	 * Update the specified resource in storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function update($id) {
		//
	}

	/**
	 * Remove the specified resource from storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function destroy($id) {
		//
	}

	public function search() {
		$search = Input::get('search_tenant');
		$requestPage = Input::get('origin');

		$tenant = Tenant::select('tenants.id', 'tenant_name')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->join('users', 'users.id', '=', 'tenants.created_by')
			->orWhere('ic_no', $search)
			->orWhere('unit_no', $search)
			->orWhere('tenant_name', 'LIKE', '%' . $search . '%')
			->where('tenants.status', 'enable')
			->where('properties.location_id', Session::get('project')->location_id)
			->get();

		if (count($tenant) == 1) {
			$tenant = $tenant->first();
			if ($requestPage === 'payment') {
				return Redirect::action('PaymentController@index', array('tenant' => $tenant->id))->with('message', 'Your search has been found. Please proceed to Bill Payment.');
			} else {
				return Redirect::action('TenantController@show', array('tenant' => $tenant->id));
			}
		} else if (count($tenant) > 1) {
			$tenantsId = $tenant->lists('id');
			// return Response::json($tenantsId);die();
			return Redirect::action('TenantController@index', array('search' => implode(',', $tenantsId)))
				->with('message', count($tenantsId) . ' Record (s) found.');
		} else {
			return Redirect::to(URL::previous())->with('error', 'Sorry, your search could not be found.');
		}
	}

	public function submitPaymentPreview() {

		// get input from ajax
		$rentalAmountPaid = Input::get('rental_amount');
		$waterAmountPaid = Input::get('water_amount');
		$waterDatePaid = Input::get('water_date');

		$otherAmountPaid = Input::get('other_amount');
		$otherDatePaid = Input::get('other_date');
		$id = Input::get('tenant_id');

		$tenant = Tenant::find($id);

		$rentalRate = Tenant::getRentalRateByTenantId($id);

		// get this month rental bill
		$currRentalBill = Bill::getCurrentRentalBillByTenantId($id);
		// get all except current month unpaid rental bills
		$rentalBills = Bill::getOutstandingRentalBillsByTenantId($id);

		// array to store month included in payment
		$rentalPayments = array();
		$waterPayments = array();
		$otherPayments = array();

		// check other payment date
		if ($otherAmountPaid > 0) {
			$currentMonYear = strtotime(date('Y-m'));
			$otherPaymentMonYear = strtotime($otherDatePaid);
			$otherPayemntType = 'Current';
			if ($otherPaymentMonYear < $currentMonYear) {
				$otherPayemntType = 'Outstanding';
			} else if ($otherPaymentMonYear > $currentMonYear) {
				$otherPayemntType = 'Advanced';
			}

			$other = new stdClass(); // raw object to be return in json
			$other->amount_paid = $otherAmountPaid;
			$other->amount_due = sprintf('%0.2f', 0); // set to 0 as no more due
			$other->mon_year = date('M / Y', $otherPaymentMonYear);
			$other->type = $otherPayemntType;

			array_push($otherPayments, $other);
		}

		// check water payment date
		if ($waterAmountPaid > 0) {
			$currentMonYear = strtotime(date('Y-m'));
			$waterPaymentMonYear = strtotime($waterDatePaid);
			$waterPayemntType = 'Current';
			if ($waterPaymentMonYear < $currentMonYear) {
				$waterPayemntType = 'Outstanding';
			} else if ($waterPaymentMonYear > $currentMonYear) {
				$waterPayemntType = 'Advanced';
			}

			$water = new stdClass(); // raw object to be return in json
			$water->amount_paid = $waterAmountPaid;
			$water->amount_due = sprintf('%0.2f', 0); // set to 0 as no more due
			$water->mon_year = date('M / Y', $waterPaymentMonYear);
			$water->type = $waterPayemntType;

			array_push($waterPayments, $water);
		}

		// check rental payment and show preview
		if ($rentalAmountPaid > 0) {
			// check if payment status not fully / paid
			if ($currRentalBill->payment_status != 'paid') {

				// if paid amount equal or more, then pay full
				if ($rentalAmountPaid >= $currRentalBill->amount_due) {

					$rentalAmountPaid -= $currRentalBill->amount_due;
					$currRentalBill->amount_paid = sprintf('%0.2f', $currRentalBill->amount_due);
					$currRentalBill->amount_due = sprintf('%0.2f', 0); // set to 0 as no more due
					$currRentalBill->payment_status = 'paid';
					$currRentalBill->date_paid = date('Y-m-d H:i:s');
					$currRentalBill->mon_year = date('M / Y', strtotime($currRentalBill->issue_date));
					$currRentalBill->type = 'Current';
					array_push($rentalPayments, $currRentalBill);
				} else {

					// less money then pay partial
					$currRentalBill->amount_due = sprintf('%0.2f', ($currRentalBill->amount_due - $rentalAmountPaid));
					$currRentalBill->amount_paid = sprintf('%0.2f', $rentalAmountPaid);
					$rentalAmountPaid = 0;
					$currRentalBill->payment_status = 'partial';
					$currRentalBill->date_paid = date('Y-m-d H:i:s');
					$currRentalBill->mon_year = date('M / Y', strtotime($currRentalBill->issue_date));
					$currRentalBill->type = 'Current';
					array_push($rentalPayments, $currRentalBill);
				}
			}

			// if still have some money pay the first outstanding months
			if ($rentalAmountPaid > 0) {
				foreach ($rentalBills as $rentalBill) {

					// if amount left is equal or more, then pay full
					if ($rentalAmountPaid >= $rentalBill->amount_due) {
						$rentalAmountPaid -= $rentalBill->amount_due;
						$rentalBill->amount_paid = sprintf('%0.2f', $rentalBill->amount_due);
						$rentalBill->amount_due = sprintf('%0.2f', 0); // set to 0 as no more due
						$rentalBill->payment_status = 'paid';
						$rentalBill->date_paid = date('Y-m-d H:i:s');
						$rentalBill->mon_year = date('M / Y', strtotime($rentalBill->issue_date));
						$rentalBill->type = 'Outstanding';
						array_push($rentalPayments, $rentalBill);
					} else {

						// less money then pay partial
						$rentalBill->amount_due = sprintf('%0.2f', ($rentalBill->amount_due - $rentalAmountPaid));
						$rentalBill->amount_paid = sprintf('%0.2f', $rentalAmountPaid);
						$rentalAmountPaid = 0.00;
						$rentalBill->payment_status = 'partial';
						$rentalBill->date_paid = date('Y-m-d H:i:s');
						$rentalBill->mon_year = date('M / Y', strtotime($rentalBill->issue_date));
						$rentalBill->type = 'Outstanding';
						array_push($rentalPayments, $rentalBill);
					}

					if ($rentalAmountPaid == 0) {
						break;
					}

				}
			}

			// if had paid all outstandings and still have balance then can pay for advance
			DB::transaction(function () use ($rentalRate, $rentalAmountPaid, $tenant, &$rentalPayments) {
				$nextMonthDate = null;
				$lastBillId = Bill::orderBy('id', 'DESC')->pluck('id');
				$locationCode = Session::get('project')->location_code;

				while ($rentalAmountPaid > 0) {
					if (!$nextMonthDate) {
						$nextMonthDate = date('Y-m', strtotime("+1 months", time())) . '-01';
					} else {
						$nextMonthDate = date('Y-m', strtotime("+1 months", strtotime($nextMonthDate))) . '-01';
					}

					$bill = Bill::where('issue_date', $nextMonthDate)
					->where('tenant_id', $tenant->id)
					->where('bill_type_id', 1) // rental type
					->first();

					if (!$bill) {

						$bill = new Bill;
						$bill->bill_no = $locationCode . '-' . (1000000 + $lastBillId);
						$bill->bill_amount = $rentalRate;
						$bill->amount_due = $rentalRate;
						$bill->payment_status = 'unpaid';
						$bill->bill_type_id = 1; // rental type
						$bill->created_by = Auth::id();
						$bill->tenant_id = $tenant->id;
						$bill->issue_date = $nextMonthDate;
						$bill->save();

						$lastBillId++;
					}

					if ($bill->payment_status != 'paid') {

						// if amount left is equal or more, then pay full
						if ($rentalAmountPaid >= $bill->amount_due) {
							$rentalAmountPaid -= $bill->amount_due;
							$bill->amount_paid = sprintf('%0.2f', $bill->amount_due);
							$bill->amount_due = sprintf('%0.2f', 0); // set to 0 as no more due
							$bill->payment_status = 'paid';
							$bill->date_paid = date('Y-m-d H:i:s');
							$bill->mon_year = date('M / Y', strtotime($bill->issue_date));
							$bill->type = 'Advanced';
							array_push($rentalPayments, $bill);
						} else {
							// less money then pay partial
							$bill->amount_due = sprintf('%0.2f', ($bill->amount_due - $rentalAmountPaid));
							$bill->amount_paid = sprintf('%0.2f', $rentalAmountPaid);
							$rentalAmountPaid = 0.00;
							$bill->payment_status = 'partial';
							$bill->date_paid = date('Y-m-d H:i:s');
							$bill->mon_year = date('M / Y', strtotime($bill->issue_date));
							$bill->type = 'Advanced';
							array_push($rentalPayments, $bill);
						}
					}
				}
			});
		}

		return Response::json(array('water' => $waterPayments, 'rental' => $rentalPayments, 'other' => $otherPayments));
	}

	public function submitPayment() {
		$accountBalance = Input::get('balance');
		$rentalBills = Input::get('rental') ? Input::get('rental') : [];
		$waterBill = Input::get('water') ? Input::get('water') : 0;
		$waterDate = Input::get('water_date') ? Input::get('water_date') : '';
		$otherDate = Input::get('other_date') ? Input::get('other_date') : '';
		$otherBill = Input::get('other') ? Input::get('other') : 0;
		$tenantId = Input::get('tenant_id');

		$locationCode = Session::get('project')->location_code;
		$lastPaymentId = Payment::orderBy('id', 'DESC')->pluck('id') ? Payment::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

		$printIds = array();
		// Begin transaction, then rollback with error message if failed
		DB::beginTransaction();

		//$i = $lastPaymentId;
		//$i = $receiptNumberSQL + 1;
		
		try {

			// pay rentals
			foreach ($rentalBills as $rentalBill) {

				//ain 20160601 start
				
				
				if($rentalBill['type'] == 'Outstanding'){
				
					$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
							->where('payment_type','TS')
							->orderBy('running_no','DESC')
							->pluck('running_no');
					$ts = $receiptNumberSQL + 1;
					$code = 'TS';
					$paymentType = 'Tunggakan Sewa';
					
					
					$serialNo = 1000000 + $ts;
					//ain 20160601 end
					// create payment entry
					$payment = new Payment;
					$payment->created_by = Auth::id();
					$payment->amount_paid = $rentalBill['amount_paid'];
					$payment->bill_id = $rentalBill['id'];
					$payment->receipt_no = $code . '-' . $serialNo;
					$payment->save();
					
					$receiptNumber = new ReceiptNumber;
					$receiptNumber->location_code = $locationCode;
					$receiptNumber->bill_type_id = 1;
					$receiptNumber->payment_type = 'TS';
					$receiptNumber->running_no = $ts;
					$receiptNumber->serial_no = 1000000 + $ts;
					$receiptNumber->save();
					//ain 20160531 end
					
					$ts++;
					
					
				}
				else{
				
					$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
							->where('payment_type','SS')
							->where('bill_type_id',1)
							->orderBy('running_no','DESC')
							->pluck('running_no');
					$ss = $receiptNumberSQL + 1;
					$code = 'SS';
					$paymentType = 'Sewa Semasa';
					
					$serialNo = 1000000 + $ss;
					//ain 20160601 end
					// create payment entry
					$payment = new Payment;
					$payment->created_by = Auth::id();
					$payment->amount_paid = $rentalBill['amount_paid'];
					$payment->bill_id = $rentalBill['id'];
					$payment->receipt_no = $code . '-' . $serialNo;
					$payment->save();
					
					$receiptNumber = new ReceiptNumber;
					$receiptNumber->location_code = $locationCode;
					$receiptNumber->bill_type_id = 1;
					$receiptNumber->payment_type = 'SS';
					$receiptNumber->running_no = $ss;
					$receiptNumber->serial_no = 1000000 + $ss;
					$receiptNumber->save();
					//ain 20160531 end
					$ss++;
					
				}
				
				array_push($printIds, $payment->id);
				
				// Update bill with current payment
				$bill = Bill::find($rentalBill['id']);
				$bill->amount_due = $rentalBill['amount_due'];
				$bill->payment_status = $rentalBill['payment_status'];
				$bill->save();

			}
			if ($waterBill > 0) {
				$lastId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

				$payWaterbill = new Bill;
				$payWaterbill->issue_date = date('Y-m', strtotime($waterDate)) . '-01 00:00:00';
				$payWaterbill->bill_no = $locationCode . '-' . (1000000 + $lastId);
				$payWaterbill->bill_amount = $waterBill;
				$payWaterbill->amount_due = 0;
				$payWaterbill->created_by = Auth::id();
				$payWaterbill->tenant_id = $tenantId;
				$payWaterbill->bill_type_id = 2; // water
				$payWaterbill->payment_status = 'paid';
				$payWaterbill->save();
				
				$waterDatePayment = date('Y-m', strtotime($waterDate));
				$waterDatePaid = Input::get('water_date');
				$currentMonYear = strtotime(date('Y-m'));
				$waterPaymentMonYear = strtotime($waterDatePaid);
				$waterPayemntType = 'Current';
				if ($waterPaymentMonYear < $currentMonYear) {
					$waterPayemntType = 'Outstanding';
					$code = 'AT';
					$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
							->where('payment_type',$code)
							->where('bill_type_id',2)
							->orderBy('running_no','DESC')
							->pluck('running_no');
					$at = $receiptNumberSQL + 1;
					//$code = 'AS';
					$paymentType = 'Air Tunggakan';
					
					$serialNo = 1000000 + $at;
					
					$receiptNumber = new ReceiptNumber;
					$receiptNumber->location_code = $locationCode;
					$receiptNumber->bill_type_id = 2;
					$receiptNumber->payment_type = 'AT';
					$receiptNumber->running_no = $at;
					$receiptNumber->serial_no = 1000000 + $at;
					$receiptNumber->save();
					$at++;
				} else {
					$waterPayemntType = 'Advanced';
					$code = 'AS';
					$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
							->where('payment_type',$code)
							->where('bill_type_id',2)
							->orderBy('running_no','DESC')
							->pluck('running_no');
					$as = $receiptNumberSQL + 1;
					//$code = 'AS';
					$paymentType = 'Air Semasa';
					
					$serialNo = 1000000 + $as;
					
					$receiptNumber = new ReceiptNumber;
					$receiptNumber->location_code = $locationCode;
					$receiptNumber->bill_type_id = 2;
					$receiptNumber->payment_type = 'AS';
					$receiptNumber->running_no = $as;
					$receiptNumber->serial_no = 1000000 + $as;
					$receiptNumber->save();
					$as++;
				}
				
				$payment = new Payment;
				$payment->created_by = Auth::id();
				$payment->amount_paid = $payWaterbill->bill_amount;
				$payment->bill_id = $payWaterbill->id;
				$payment->receipt_no = $code . '-' . $serialNo;
				$payment->save();
				array_push($printIds, $payment->id);
			}
			// pay LPHS, MBPJ, MBI etc
			if ($otherBill > 0) {
				$otherBillTypeId = Bill::where('tenant_id', $tenantId)
					->whereNotIn('bill_type_id', array(1, 2))
					->pluck('id');

				$payOtherbill = Bill::find($otherBillTypeId);
				$payOtherbill->amount_due = $payOtherbill->amount_due - $otherBill;

				if ($otherBill == $payOtherbill->amount_due) {
					$payOtherbill->payment_status = 'paid';
				} else {
					$payOtherbill->payment_status = 'partial';
				}

				$payOtherbill->save();
				
				$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
							->where('payment_type','TS')
							->orderBy('running_no','DESC')
							->pluck('running_no');
				$ts = $receiptNumberSQL + 1;
				$code = 'TS';
				$paymentType = 'Tunggakan Sewa';
				
				
				$serialNo = 1000000 + $ts;
				//ain 20160601 end
				
				$otherPayment = new Payment;
				$otherPayment->created_by = Auth::id();
				$otherPayment->amount_paid = $otherBill;
				$otherPayment->bill_id = $payOtherbill->id;
				$otherPayment->receipt_no = $code . '-' . $serialNo;
				$otherPayment->optional_bill_date = date('Y-m', strtotime($otherDate)) . '-01 00:00:00';
				$otherPayment->save();

				array_push($printIds, $otherPayment->id);
				
				$receiptNumber = new ReceiptNumber;
				$receiptNumber->location_code = $locationCode;
				$receiptNumber->bill_type_id = $payOtherbill->bill_type_id;
				$receiptNumber->payment_type = 'TS';
				$receiptNumber->running_no = $ts;
				$receiptNumber->serial_no = 1000000 + $ts;
				$receiptNumber->save();
				//ain 20160531 end
				
				$ts++;
				
			}

			DB::commit();

			$printURL = action('PaymentController@printPayment', array('id' => implode(',', $printIds)));
			return Response::json(array('status' => 'ok', 'message' => 'Bill payment has been successfully made.', 'print_url' => $printURL));
		} catch (Exception $e) {
			DB::rollback();
			return Response::json(array('status' => 'error', 'message' => $e->getMessage()));
		}
	}

	public function printPayment() {
		$data = array();

		if (Input::has('type') && Input::has('tenant') && Input::get('type') == 'deposit') {
			//Ain 20151202	
			/*$receipt = Deposit::join('tenants', 'tenants.id', '=', 'deposits.tenant_id')
				->join('properties', 'properties.id', '=', 'tenants.property_id')
				->join('users', 'users.id', '=', 'deposits.created_by')
				->where('tenant_id', Input::get('tenant'))->first();*/
			
			$receipt = Deposit::select('tenants.tenant_name', 'properties.unit_no', 'deposits.description', 'deposits.one_month_rental','deposits.one_month_date', 'deposits.two_month_rental', 'deposits.utilities', 'deposits.management_fee', 'deposits.total_deposit','deposits.created_at as payment_date', 'users.name', 'deposits.receipt_no')
				->join('tenants', 'tenants.id', '=', 'deposits.tenant_id')
				->join('properties', 'properties.id', '=', 'tenants.property_id')
				->join('users', 'users.id', '=', 'deposits.created_by')
				->where('tenant_id', Input::get('tenant'))->first();			

			$detail = array();
			$detail['NAMA'] = $receipt->tenant_name;
			$detail['ALAMAT'] = $receipt->unit_no;
			$detail['KETERANGAN'] = $receipt->description;
			$detail['BAYARAN 1 BULAN'] = 'RM ' . sprintf('%0.2f', ($receipt->one_month_rental)) . ' (' . date('m / Y', strtotime($receipt->one_month_date)) . ')';
			$detail['BAYARAN 2 BULAN'] = 'RM ' . sprintf('%0.2f', ($receipt->two_month_rental));
			$detail['BAYARAN UTILITY'] = 'RM ' . sprintf('%0.2f', ($receipt->utilities));
			$detail['BAYARAN PENGURUSAN'] = 'RM ' . sprintf('%0.2f', ($receipt->management_fee));
			$detail['JUMLAH'] = 'RM ' . sprintf('%0.2f', ($receipt->total_deposit));
			//Ain 20151202			
			//$detail['TARIKH / MASA'] = date('d-m-Y h:i:s A'); 
			$detail['TARIKH / MASA'] = date('d-m-Y h:i:s A', strtotime($receipt->payment_date)); 
			$detail['PEGAWAI'] = $receipt->name;

			$data['printReceipts'] = array();
			array_push($data['printReceipts'], array('detail' => $detail, 'receipt_no' => $receipt->receipt_no));

			return View::make('receipt.payment', $data);
		} else {
			$receiptsId = explode(',', Input::get('id'));

			$receipts = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.bill_type_id', 'bill_types.bill_type_name', 'bills.issue_date as bill_date', 'name', 'tenant_name', 'unit_no', 'rental_rate', 'optional_bill_date')
				->join('bills', 'bills.id', '=', 'payments.bill_id')
				->join('bill_types', 'bills.bill_type_id', '=', 'bill_types.id')
				->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
				->join('properties', 'properties.id', '=', 'tenants.property_id')
				->join('users', 'users.id', '=', 'payments.created_by')
				->whereIn('payments.id', $receiptsId)
				->get();

			$printReceipts = array();

			foreach ($receipts as $receipt) {

				$detail['NAMA'] = $receipt->tenant_name;
				$detail['ALAMAT'] = $receipt->unit_no;
				if ($receipt->bill_type_id == 1) {
					$detail['KADAR SEWA'] = 'RM ' . $receipt->rental_rate;
				}

				$detail['KETERANGAN'] = '';
				switch ($receipt->bill_type_id) {
					case 1:$detail['KETERANGAN'] = 'Sewa Bulanan Rumah';
						break;
					case 2:$detail['KETERANGAN'] = 'Bill Air Rumah';
						break;
					default:$detail['KETERANGAN'] = 'Bayaran ' . $receipt->bill_type_name;
				}

				if (!in_array($receipt->bill_type_id, array(1, 2))) {
					$detail['KETERANGAN'] .= ' (' . date('m/Y', strtotime($receipt->optional_bill_date)) . ')';
				
				} else {
					$detail['KETERANGAN'] .= ' (' . date('m/Y', strtotime($receipt->bill_date)) . ')';
				}
				$detail['JUMLAH BAYARAN'] = 'RM ' . sprintf('%0.2f', ($receipt->amount_paid));
				$detail['TARIKH / MASA'] = date('d-m-Y h:i:s A', strtotime($receipt->payment_date));
				$detail['PEGAWAI'] = $receipt->name;

				array_push($printReceipts, array('detail' => $detail, 'receipt_no' => $receipt->receipt_no));
			}

			$data['printReceipts'] = $printReceipts;
			$data['receiptCopies'] = array('PHSSB', 'MBPJ');
		}

		return View::make('receipt.payment', $data);
	}

	public function checkPayment() {
		$receiptNo = Input::get('receipt_no');

		$paymentId = Payment::where('receipt_no', $receiptNo)->pluck('id');

		$response = array();
		if ($paymentId) {
			$response = array(
				'status' => 'ok',
				'url' => action('PaymentController@printPayment', array('id' => $paymentId)),
				'message' => 'Receipt found.',
			);
		} else {
			$response = array(
				'status' => 'error',
				'url' => '',
				'message' => 'Receipt not found.',
			);
		}

		return Response::json($response);
	}

}
