<?php

class ProjectController extends \BaseController {

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index() {
	// get all projects not type admin with pagination of 10
	$projects = Project::where('project_name', '<>', 'ADMIN')
		->where('status', 'enable')->paginate(20);

	// pagination links and text
	$data['paginationLinks'] = $projects->appends(Input::except('page'))->links();
	$data['paginationText'] = 'Showing ' . $projects->getFrom() . ' - ' . $projects->getTo() . ' of ' . $projects->getTotal();

	$data['projects'] = $projects;

	return View::make('project.list', $data);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create() {
	$data = array();
	return View::make('project.form', $data);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store() {
	// validate post fields
	$rules = array(
	    'project_name' => 'required|unique:projects',
	    'project_code' => 'required',
	);
	
	$validator = Validator::make(Input::all(), $rules);

	// process the add
	if ($validator->fails()) {
	    return Redirect::route('project.create')
			    ->withErrors($validator)
			    ->withInput(Input::all());
	} else {

	    // get input
	    $project_name = Input::get('project_name');
	    $project_code = Input::get('project_code');
	    
	    // create new project with inputs
	    $project = new Project;
	    $project->project_name = $project_name;
	    $project->project_code = $project_code;
	    $project->save();

	    // redirect to user routing with message
	    return Redirect::to('project')->with('message', 'Project has been successfully added.');
	}
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id) {
	//
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id) {
	$data = array();
	$data['project'] = Project::find($id);
	
	return View::make('project.form', $data);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id) {
	// validate post fields
	$rules = array(
	    'project_name' => 'required|unique:projects,project_name,' . $id,
	    'project_code' => 'required',
	);
	
	$validator = Validator::make(Input::all(), $rules);

	// process the add
	if ($validator->fails()) {
	    return Redirect::route('project.create')
			    ->withErrors($validator)
			    ->withInput(Input::all());
	} else {

	    // get input
	    $project_name = Input::get('project_name');
	    $project_code = Input::get('project_code');
	    
	    // create new project with inputs
	    $project = Project::find($id);
	    $project->project_name = $project_name;
	    $project->project_code = $project_code;
	    $project->save();

	    // redirect to user routing with message
	    return Redirect::to('project')->with('message', 'Project has been successfully updated.');
	}
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id) {
	$project = Project::find($id);
	$project->status = 'disable';
	$project->save();
    }
}
