<?php

class PropertyController extends \BaseController {

	/**
	 * Display a listing of the resource.
	 *
	 * @return Response
	 */
	public function index() {

		// get all users not type admin with pagination of 10
		$properties = Property::select('properties.id', 'unit_no', 'property_type', 'block', 'vacancy', 'location_name')
			->join('locations', 'locations.id', '=', 'properties.location_id')
			->where('properties.status', 'enable')
			->where('locations.id', Session::get('project')->location_id)
			->orderBy('locations.id')
			->orderBy('unit_no');

		if (Input::has('block') && strtolower(Input::get('block')) != 'all') {
			$properties = $properties->where('block', strtolower(Input::get('block')));
		}
		$properties = $properties->paginate(20);

		// pagination links and text
		$data['paginationLinks'] = $properties->appends(Input::except('page'))->links();
		$data['paginationText'] = 'Showing ' . $properties->getFrom() . ' - ' . $properties->getTo() . ' of ' . $properties->getTotal();

		$data['properties'] = $properties;

		$data['showing'] = Input::get('block') ? Input::get('block') : 'all';
		$data['blocks'] = array('a', 'b', 'c', 'd');

		return View::make('property.list', $data);
	}

	/**
	 * Show the form for creating a new resource.
	 *
	 * @return Response
	 */
	public function create() {
		$data = array();
		$data['locationOptions'] = Location::getLocationOptions();
		$data['scripts'] = array('date-field-property.js');
		return View::make('property.form', $data);
	}

	/**
	 * Store a newly created resource in storage.
	 *
	 * @return Response
	 */
	public function store() {

		// validate post fields
		$rules = array(
			'location_id' => 'required',
			'property_type' => 'required',
			'unit_no' => 'required',
			'block' => 'required',
			'line1' => 'required',
			'city' => 'required',
			'state' => 'required',
			'postcode' => 'required|numeric',
			'country' => 'required',
			'area' => 'numeric',
			'value' => 'numeric',
		);

		$messages = array('location_id.required' => 'The location is required. Please select again.');

		$validator = Validator::make(Input::all(), $rules, $messages);

		// process the add
		if ($validator->fails()) {
			return Redirect::route('property.create')
				->withErrors($validator)
				->withInput(Input::all());
		} else {

			// get input
			$location_id = Input::get('location_id');
			$unit_no = Input::get('unit_no');
			$block = Input::get('block');
			$line1 = Input::get('line1');
			$line2 = Input::get('line2');
			$city = Input::get('city');
			$state = Input::get('state');
			$country = Input::get('country');
			$postcode = Input::get('postcode');
			$lot_type = Input::get('lot_type');
			$plot_no = Input::get('plot_no');
			$lot_status = Input::get('lot_status');
			$value = Input::get('value');
			$date_valued = Input::get('date_valued');
			$area = Input::get('area');
			$property_type = Input::get('property_type');

			// create new property with inputs
			$property = new Property;
			$property->location_id = $location_id;
			$property->unit_no = $unit_no;
			$property->block = $block;
			$property->line1 = $line1;
			$property->line2 = $line2;
			$property->city = $city;
			$property->state = $state;
			$property->country = $country;
			$property->postcode = $postcode;
			$property->lot_type = $lot_type;
			$property->plot_no = $plot_no;
			$property->value = $value;
			$property->date_valued = date('Y-m-d H:i:s', strtotime($date_valued));
			$property->area = $area;
			$property->property_type = $property_type;
			$property->save();

			// redirect to user routing with message
			return Redirect::to('property')->with('message', 'New property has been successfully added.');
		}
	}

	/**
	 * Display the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function show($id) {
		//
	}

	/**
	 * Show the form for editing the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function edit($id) {
		$data = array();
		$data['property'] = Property::find($id);
		$data['locationOptions'] = Location::getLocationOptions();
		$data['scripts'] = array('date-field-property.js');

		if ($data['property']->date_valued != '0000-00-00 00:00:00') {
			$data['property']->date_valued = date('d-m-Y', strtotime($data['property']->date_valued));
		} else {
			$data['property']->date_valued = '';
		}
		return View::make('property.form', $data);
	}

	/**
	 * Update the specified resource in storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function update($id) {
		// validate post fields
		$rules = array(
			'location_id' => 'required',
			'property_type' => 'required',
			'unit_no' => 'required',
			'block' => 'required',
			'line1' => 'required',
			'city' => 'required',
			'state' => 'required',
			'postcode' => 'required|numeric',
			'country' => 'required',
			'area' => 'numeric',
			'value' => 'numeric',
		);

		$messages = array('location_id.required' => 'The location is required. Please select again.');

		$validator = Validator::make(Input::all(), $rules, $messages);

		// process the add
		if ($validator->fails()) {
			return Redirect::route('property.update', $id)
				->withErrors($validator)
				->withInput(Input::all());
		} else {

			// get input
			$location_id = Input::get('location_id');
			$unit_no = Input::get('unit_no');
			$block = Input::get('block');
			$line1 = Input::get('line1');
			$line2 = Input::get('line2');
			$city = Input::get('city');
			$state = Input::get('state');
			$country = Input::get('country');
			$postcode = Input::get('postcode');
			$lot_type = Input::get('lot_type');
			$plot_no = Input::get('plot_no');
			$lot_status = Input::get('lot_status');
			$value = Input::get('value');
			$date_valued = Input::get('date_valued');
			$area = Input::get('area');
			$property_type = Input::get('property_type');

			// create new property with inputs
			$property = Property::find($id);
			$property->location_id = $location_id;
			$property->unit_no = $unit_no;
			$property->block = $block;
			$property->line1 = $line1;
			$property->line2 = $line2;
			$property->city = $city;
			$property->state = $state;
			$property->country = $country;
			$property->postcode = $postcode;
			$property->lot_type = $lot_type;
			$property->plot_no = $plot_no;
			$property->value = $value;
			$property->date_valued = date('Y-m-d H:i:s', strtotime($date_valued));
			$property->area = $area;
			$property->property_type = $property_type;
			$property->save();

			// redirect to user routing with message
			return Redirect::route('property.edit', $id)->with('message', 'Property has been successfully updated.');
		}
	}

	/**
	 * Remove the specified resource from storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function destroy($id) {
		$property = Property::find($id);
		$property->status = 'disable';
		$property->save();
	}

	public function check() {
		$unitNo = Input::get('unit');

		$property = Property::where('unit_no', $unitNo)
			->first();

		$class = 'text-danger'; // bootsrap text class to be used
		$response = array('status' => 'error', 'message' => 'Invalid request', 'class' => $class);

		if (!$property) {
			$response = array('status' => 'error', 'message' => 'Property not exist!', 'class' => $class);
		} else {
			if ($property->vacancy == 'unavailable') {
				$response = array('status' => 'error', 'message' => 'Property is unavailable!', 'class' => $class);
			} else {
				$response = array('status' => 'ok', 'message' => 'Property is available!', 'class' => 'text-success');
			}
		}

		return Response::json($response);
	}

	public function getHistory($id) {

		$data = array();

		$data['history'] = Property::select('tenant_name', 'property_history.status',
			'property_history.created_at as start_date', 'property_history.updated_at as end_date')
			->join('property_history', 'property_history.property_id', '=', 'properties.id')
			->join('tenants', 'property_history.tenant_id', '=', 'tenants.id')
			->where('properties.id', $id)
			->get();

		return View::make('property.history', $data);
	}

}
