<?php

class RemindersController extends Controller {

    /**
     * Display the password reminder view.
     *
     * @return Response
     */
    public function getRemind() {
	$data['title'] = 'Forgot password';
	return View::make('password.remind', $data);
    }

    /**
     * Handle a POST request to remind a user of their password.
     *
     * @return Response
     */
    public function postRemind() {
	$response = Password::remind(Input::only('email'), function($message) {
            $message->subject('PHSSB: Password Reminder');
        });
	
	switch ($response) {
	    case Password::INVALID_USER:
		return Redirect::back()->with('error', 'Invalid user');

	    case Password::REMINDER_SENT:
		return Redirect::back()->with('message', sprintf('An e-mail will be sent to your address (%s) with instructions to reset your password.', e(Input::get('email'))));
	}
    }

    /**
     * Display the password reset view for the given token.
     *
     * @param  string  $token
     * @return Response
     */
    public function getReset($token = null) {
	if (is_null($token))
	    App::abort(404);

	$data = array();
        $data['title'] = 'Password Reset';
	
	return View::make('password.reset', $data)->with('token', $token);
    }

    /**
     * Handle a POST request to reset a user's password.
     *
     * @return Response
     */
    public function postReset() {
	$credentials = Input::only(
			'email', 'password', 'password_confirmation', 'token'
	);

	$response = Password::reset($credentials, function($user, $password) {
		    $user->password = Hash::make($password);

		    $user->save();
		});

	switch ($response) {
	    case Password::INVALID_PASSWORD:
	    case Password::INVALID_TOKEN:
	    case Password::INVALID_USER:
		return Redirect::back()->with('error', Lang::get($response));

	    case Password::PASSWORD_RESET:
		return Redirect::to('/')->with('message', 'Your password has been successfully changed');
	}
    }

}
