<?php

class ReportController extends \BaseController {

    /**
     * Display a report.
     *
     * @return Response
     */
    public function index() {
    	$data = array();
    	$query = null;
    	if (Input::has('report_type') && Input::get('report_type') == 'deposit') {

    		$query = Deposit::select('deposits.id', 'tenants.id as tenant_id', 'tenant_name', 'unit_no', 'receipt_no', 'total_deposit', 'deposits.created_at as paid_date')
    		->join('tenants', 'tenants.id', '=', 'deposits.tenant_id')
    		->join('properties', 'properties.id', '=', 'tenants.property_id')
            ->join('locations', 'properties.location_id', '=', 'locations.id')
            ->where('locations.id', Session::get('project')->location_id)
    		->orderBy('deposits.created_at', 'DESC')
    		->orderBy('tenants.id');

	    // filtering date entered by user
    		if (Input::has('start_date') && Input::has('end_date')) {

    			if (Input::get('start_date') == Input::get('end_date')) {
    				$query = $query->where('deposits.created_at', 'LIKE', date('Y-m-d', strtotime(Input::get('start_date'))) . ' %');
    			} else {
    				$query = $query->whereBetween('deposits.created_at', array(date('Y-m-d', strtotime(Input::get('start_date'))), date('Y-m-d', strtotime(Input::get('end_date') . ' + 1 day'))));
    			}
    		} else if (Input::has('start_date') && !Input::has('end_date')) {
    			$query = $query->where('deposits.created_at', 'LIKE', date('Y-m-d', strtotime(Input::get('start_date'))) . ' %');
    		}

    		$data['totalAmount'] = sprintf('%0.2f', $query->sum('total_deposit'));
    	} else {
		//20151203 Ain
		//$query = Payment::select('payments.id', 'tenants.id as tenant_id', 'tenant_name', 'unit_no', 'receipt_no', 'bills.issue_date', 'amount_paid', 'payments.created_at as paid_date', 'bill_type_name', 'bill_type_id')
    		$query = Payment::select('payments.id', 'tenants.id as tenant_id', 'tenant_name', 'unit_no', 'receipt_no', 'bills.issue_date', 'amount_paid', 'payments.created_at as paid_date', 'bill_type_name', 'bill_type_id', 'payments.optional_bill_date as bill_date')
    		->join('bills', 'payments.bill_id', '=', 'bills.id')
    		->join('bill_types', 'bills.bill_type_id', '=', 'bill_types.id')
    		->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    		->join('properties', 'properties.id', '=', 'tenants.property_id')
            ->join('locations', 'properties.location_id', '=', 'locations.id')
            ->where('locations.id', Session::get('project')->location_id)
    		->where('bills.payment_status', '<>', 'unpaid')
    		->orderBy('payments.created_at', 'DESC')
    		->orderBy('tenants.id');

	    // filtering date entered by user
    		if (Input::has('start_date') && Input::has('end_date')) {

    			if (Input::get('start_date') == Input::get('end_date')) {
    				$query = $query->where('payments.created_at', 'LIKE', date('Y-m-d', strtotime(Input::get('start_date'))) . ' %');
    			} else {
    				$query = $query->whereBetween('payments.created_at', array(date('Y-m-d', strtotime(Input::get('start_date'))), date('Y-m-d', strtotime(Input::get('end_date') . ' + 1 day'))));
    			}
    		} else if (Input::has('start_date') && !Input::has('end_date')) {
    			$query = $query->where('payments.created_at', 'LIKE', date('Y-m-d', strtotime(Input::get('start_date'))) . ' %');
    		}

	    // filter type
    		if (Input::has('report_type')) {
    			if (Input::get('report_type') == 'rental') {
    				$query = $query->where('bill_type_id', '<>', 2);
    			} else if (Input::get('report_type') == 'water') {
    				$query = $query->where('bill_type_id', 2);
    			}
    		} else {
    			$query = $query->where('bill_type_id', 1);
    		}

    		$data['totalAmount'] = sprintf('%0.2f', $query->sum('amount_paid'));
    	}

    	if (Input::has('format')) {
    		$data['payments'] = $query->get();
    		$data['project'] = Session::get('project');
    		return View::make('report.print', $data);
    	} else {

    		$payments = $query->paginate(200);

    		$data['paginationLinks'] = $payments->appends(Input::except('page'))->links();
    		$data['paginationText'] = 'Showing ' . $payments->getFrom() . ' - ' . $payments->getTo() . ' of ' . $payments->getTotal();
    		$data['payments'] = $payments;

    		$data['scripts'] = array('report-filter.js',);

    		return View::make('report.index', $data);
    	}
    }

    public function submitFilter() {

    	$inputs = Input::all();
    	unset($inputs['_token']);

	// Taking out empty field from filter
    	foreach ($inputs as $key => $value) {
    		if ($value == '')
    			unset($inputs[$key]);
    	}

    	if (Input::has('start_date') && Input::has('end_date')) {
    		$start = strtotime(Input::get('start_date'));
    		$end = strtotime(Input::get('end_date'));

    		if ($start > $end) {
    			return Redirect::action('ReportController@index', $inputs)->with('error', 'Invalid. From Date cannot be greater than To Date.');
    		}
    	}

    	return Redirect::action('ReportController@index', $inputs);
    }

    public function dataAnalysis() {

    	$currMonth = date('Y-m') . '%';
    	$previousMonth = date('Y-m', strtotime(date('Y-m') . '-01 -1 month')) . '%';

    	if (Input::has('mon_year')) {
    		$monYear = Input::get('mon_year');

    		$currMonth = date('Y-m', strtotime($monYear)) . '%';
    		$previousMonth = date('Y-m', strtotime($currMonth . '-01 -1 month')) . '%';
    	}


    	$totalTenants = Tenant::join('bills', 'bills.tenant_id', '=', 'tenants.id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('bills.issue_date', 'LIKE', $currMonth)
    	->where('bills.bill_type_id', 1)
    	->count();

		// total of paid and unpaid
    	$totalRent124 = Tenant::join('bills', 'bills.tenant_id', '=', 'tenants.id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('rental_rate', 124)
    	->count();

    	$totalRent250 = Tenant::join('bills', 'bills.tenant_id', '=', 'tenants.id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('rental_rate', 250)
    	->where('bills.issue_date', 'LIKE', $currMonth)
    	->where('bills.bill_type_id', 1)
    	->count();

		// list that have paid
    	$alreadyPaid124CurrentMonthList = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('payment_status', 'paid')
    	->where('bill_type_id', 1)
    	->where('bill_amount', 124)
    	->where('issue_date', 'LIKE', $currMonth)
    	->get();

    	$alreadyPaid250CurrentMonthList = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('payment_status', 'paid')
    	->where('bill_type_id', 1)
    	->where('bill_amount', 250)
    	->where('issue_date', 'LIKE', $currMonth)
    	->get();

    	$alreadyPaid250CurrentMonth = count($alreadyPaid250CurrentMonthList);

    	$alreadyPaid124CurrentMonth = count($alreadyPaid124CurrentMonthList);

    	$notPaid250CurrentMonth = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('payment_status', '<>', 'paid')
    	->where('bill_type_id', 1)
    	->where('bill_amount', 250)
    	->where('issue_date', 'LIKE', $currMonth)
    	->count();

    	$notPaid124CurrentMonth = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('payment_status', '<>', 'paid')
    	->where('bill_type_id', 1)
    	->where('bill_amount', 124)
    	->where('issue_date', 'LIKE', $currMonth)
    	->count();

    	$notPaidCurrentMonth = Bill::join('tenants', 'tenants.id', '=', 'bills.tenant_id')
    	->join('properties', 'properties.id', '=', 'tenants.property_id')
    	->where('properties.location_id', Session::get('project')->location_id)
    	->where('payment_status', '<>', 'paid')
    	->where('bill_type_id', 1)
    	->where('issue_date', 'LIKE', $currMonth)
    	->count();

    	$percentagePaid124CurrentMonth = $alreadyPaid124CurrentMonth > 0 ? $alreadyPaid124CurrentMonth / $totalTenants * 100 : 0;
    	$percentagePaid250CurrentMonth = $alreadyPaid250CurrentMonth > 0 ? $alreadyPaid250CurrentMonth / $totalTenants * 100 : 0;
    	$percentageNotPaid124CurrentMonth = $notPaid124CurrentMonth > 0 ? $notPaid124CurrentMonth / $totalTenants * 100 : 0;
    	$percentageNotPaid250CurrentMonth = $notPaid250CurrentMonth > 0 ? $notPaid250CurrentMonth / $totalTenants * 100 : 0;
    	$percentageNotPaidCurrentMonth = $notPaidCurrentMonth > 0 ? $notPaidCurrentMonth / $totalTenants * 100 : 0;

		// detail for RM124 paid break down
    	$paid124With124PreviousMonth = 0;
    	$paid124With250PreviousMonth = 0;
    	$paid124WithBelow124PreviousMonth = 0;
    	$paid124WithNoPaidPreviousMonth = 0;

    	foreach ($alreadyPaid124CurrentMonthList as $row) {
    		$bill = Bill::where('bill_type_id', 1)
    		->where('issue_date', 'LIKE', $previousMonth)
    		->where('tenant_id', $row->tenant_id)
    		->first();

    		if ($bill) {
    			if ($bill->payment_status != 'paid') {
    				$paid124WithNoPaidPreviousMonth++;
    			} else if ($bill->bill_amount == 250) {
    				$paid124With250PreviousMonth++;
    			} else if ($bill->bill_amount == 124) {
    				$paid124With124PreviousMonth++;
    			} else if ($bill->bill_amount < 250) {
    				$paid124WithBelow124PreviousMonth++;
    			}
    		}
    	}

		// detail for RM250 paid break down
    	$paid250With250PreviousMonth = 0;
    	$paid250With124to250PreviousMonth = 0;
    	$paid250WithNoPaidPreviousMonth = 0;

    	foreach ($alreadyPaid250CurrentMonthList as $row) {
    		$bill = Bill::where('bill_type_id', 1)
    		->where('issue_date', 'LIKE', $previousMonth)
    		->where('tenant_id', $row->tenant_id)
    		->first();
    		if ($bill) {
    			if ($bill->payment_status != 'paid') {
    				$paid250WithNoPaidPreviousMonth++;
    			} else if ($bill->bill_amount == 250) {
    				$paid250With250PreviousMonth++;
    			} else if ($bill->bill_amount > 124 && $bill->bill_amount < 250) {
    				$paid250With124to250PreviousMonth++;
    			}
    		}
    	}

	// water details
    	$alreadyPaidWaterCurrentMonth = Bill::where('payment_status', 'paid')
		->where('bill_type_id', 2) // type water
		->where('issue_date', 'LIKE', $currMonth)
		->count();

		$totalWaterBill = $totalTenants;

		$notPaidWaterCurrentMonth = $totalWaterBill - $alreadyPaidWaterCurrentMonth;
		$percentageNotPaidWaterCurrentMonth = $notPaidWaterCurrentMonth > 0 ? $notPaidWaterCurrentMonth / $totalWaterBill * 100 : 0;
		$percentagePaidWaterCurrentMonth = $alreadyPaidWaterCurrentMonth > 0 ? $alreadyPaidWaterCurrentMonth / $totalWaterBill * 100 : 0;


		$data = array(
			'totalTenants' => $totalTenants,
			'totalRent124' => $totalRent124,
			'totalRent250' => $totalRent250,
			'alreadyPaid124CurrentMonth' => $alreadyPaid124CurrentMonth,
			'alreadyPaid250CurrentMonth' => $alreadyPaid250CurrentMonth,
			'notPaidCurrentMonth' => $notPaidCurrentMonth,
			'notPaid124CurrentMonth' => $notPaid124CurrentMonth,
			'notPaid250CurrentMonth' => $notPaid250CurrentMonth,
			'percentagePaid124CurrentMonth' => $percentagePaid124CurrentMonth,
			'percentagePaid250CurrentMonth' => $percentagePaid250CurrentMonth,
			'percentageNotPaidCurrentMonth' => $percentageNotPaidCurrentMonth,
			'percentageNotPaid124CurrentMonth' => $percentageNotPaid124CurrentMonth,
			'percentageNotPaid250CurrentMonth' => $percentageNotPaid250CurrentMonth,
			'paid124With124PreviousMonth' => $paid124With124PreviousMonth,
			'paid124With250PreviousMonth' => $paid124With250PreviousMonth,
			'paid124WithBelow124PreviousMonth' => $paid124WithBelow124PreviousMonth,
			'paid124WithNoPaidPreviousMonth' => $paid124WithNoPaidPreviousMonth,
			'paid250With124to250PreviousMonth' => $paid250With124to250PreviousMonth,
			'paid250With250PreviousMonth' => $paid250With250PreviousMonth,
			'paid250WithNoPaidPreviousMonth' => $paid250WithNoPaidPreviousMonth,
			'alreadyPaidWaterCurrentMonth' => $alreadyPaidWaterCurrentMonth,
			'notPaidWaterCurrentMonth' => $notPaidWaterCurrentMonth,
			'notPaidWaterCurrentMonth' => $notPaidWaterCurrentMonth,
			'notPaidWaterCurrentMonth' => $notPaidWaterCurrentMonth,
			'percentageNotPaidWaterCurrentMonth' => $percentageNotPaidWaterCurrentMonth,
			'percentagePaidWaterCurrentMonth' => $percentagePaidWaterCurrentMonth
			);

$data['scripts'] = array('report-analysis.js');
return View::make('report.analysis', $data);
}

}
