<?php

class TenantController extends \BaseController {

	/**
	 * Display a listing of the resource.
	 *
	 * @return Response
	 */
	public function index() {
		$data = array();

		/*$tenants = Tenant::select('tenants.id', 'tenants.tenant_name', 'ic_no', 'unit_no', 'block', 'tenants.status', 'users.name')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->join('locations', 'properties.location_id', '=', 'locations.id')
			->join('users', 'users.id', '=', 'tenants.created_by')
			->where('locations.id', Session::get('project')->location_id);*/
		//AIN 20160111
		$tenants = Tenant::select('tenants.id', 'tenants.tenant_name', 'ic_no', 'unit_no', 'block', 'tenants.status', 'users.name','locations.description as description')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->join('locations', 'properties.location_id', '=', 'locations.id')
			->join('users', 'users.id', '=', 'tenants.created_by')
			->where('locations.id', Session::get('project')->location_id);
		//END AIN
		if (Input::has('search')) {
			$searchIdArray = explode(',', Input::get('search'));
			$tenants = $tenants->whereIn('tenants.id', $searchIdArray);
		}

		$data['blocks'] = array();
		if (Input::has('block')) {
			$blockArray = explode(',', Input::get('block'));
			$tenants = $tenants->whereIn('block', $blockArray);
			$data['blocks'] = $blockArray;
		}
		if (Input::has('status')) {
			$tenants = $tenants->where('tenants.status', Input::get('status'));
		}

		if (Input::has('format')) {
			$data['tenants'] = $tenants->get();
			$data['project'] = Session::get('project');
			return View::make('tenant.print', $data);
		} else {
			$tenants = $tenants->orderBy('tenant_name')->paginate(20);

			$data['blockActive'] = Tenant::select('block', DB::raw('count(*) as count'))
				->join('properties', 'properties.id', '=', 'tenants.property_id')
				->join('locations', 'properties.location_id', '=', 'locations.id')
				->where('tenants.status', 'enable')
				->where('locations.id', Session::get('project')->location_id)
				->groupBy('block')
				->get();

			$data['blockInactive'] = Tenant::select('block', DB::raw('count(*) as count'))
				->join('properties', 'properties.id', '=', 'tenants.property_id')
				->join('locations', 'properties.location_id', '=', 'locations.id')
				->where('tenants.status', 'disable')
				->where('locations.id', Session::get('project')->location_id)
				->groupBy('block')
				->get();

			$data['paginationLinks'] = $tenants->appends(Input::except('page'))->links();
			$data['paginationText'] = 'Showing ' . $tenants->getFrom() . ' - ' . $tenants->getTo() . ' of ' . $tenants->getTotal();
			$data['tenants'] = $tenants;
			$data['scripts'] = array('activate-record.js');

			return View::make('tenant.list', $data);
		}
	}

	/**
	 * Show the form for creating a new resource.
	 *
	 * @return Response
	 */
	public function create() {
		$data = array();
		$data['types'] = array();
		$data['availableUnitsOptions'] = Property::getAvailableUnitOptions();

		$data['scripts'] = array('select-unit.js');
		return View::make('tenant.form', $data);
	}

	/**
	 * Store a newly created resource in storage.
	 *
	 * @return Response
	 */
	public function store() {

		// validate post fields
		/*
		$rules = array(
			'ic_no' => 'required|numeric|unique:tenants',
			'tenant_name' => 'required|unique:tenants',
			'property_id' => 'required',
			'rental_rate' => 'required|numeric',
			'status' => 'required',
			'gender' => 'required',
			'marital_status' => 'required',
			'nationality' => 'required',
			'mailing_address' => 'required',
			'email' => 'email|unique:tenants',
			'race' => 'required',
			'mobile' => 'required|numeric|unique:tenants',
			'phone' => 'numeric',
			'company_fax' => 'numeric',
			'company_phone' => 'numeric',
			'other_payment_amount' => 'numeric',
		);
		*/
			$rules = array(
			'ic_no' => 'required|numeric|unique:tenants',
			'tenant_name' => 'required',
			'property_id' => 'required',
			'rental_rate' => 'required|numeric',
			'status' => 'required',
			'gender' => 'required',
			'marital_status' => 'required',
			'nationality' => 'required',
			'mailing_address' => 'required',
			'email' => 'email|unique:tenants',
			'race' => 'required',
			'mobile' => 'required',
			'other_payment_amount' => 'numeric',
		);

		$validator = Validator::make(Input::all(), $rules);

		// process the add
		if ($validator->fails()) {
			return Redirect::route('tenant.create')
				->withErrors($validator)
				->withInput(Input::all());
		} else {

			$transStatus = '';
			DB::transaction(function () use (&$transStatus) {

				// get input
				$tenant_name = Input::get('tenant_name');
				$ic_no = Input::get('ic_no');
				$property_id = Input::get('property_id');
				$rental_rate = Input::get('rental_rate');
				$passport_no = Input::get('passport_no');
				$status = Input::get('status');
				$gender = Input::get('gender');
				$type = Input::get('type');
				$marital_status = Input::get('marital_status');
				$marital_status_text = Input::get('marital_status_text');
				$nationality = Input::get('nationality');
				$mailing_address = Input::get('mailing_address');
				$race = Input::get('race');
				$race_text = Input::get('race_text');
				$mobile = Input::get('mobile');
				$phone = Input::get('phone');
				$email = Input::get('email');
				$company_name = Input::get('company_name');
				$business_type = Input::get('business_type');
				$company_address = Input::get('company_address');
				$company_phone = Input::get('company_phone');
				$company_fax = Input::get('company_fax');
				$other_payment = Input::get('other_payment');
				$other_payment_amount = Input::get('other_payment_amount');

				$property = Property::find($property_id);

				if ($property) {
					// set property vacancy to unvailable
					$property->vacancy = 'unavailable';
					$property->status = 'disable';
					$property->save();

					//  create new tenant with inputs
					$tenant = new Tenant;
					$tenant->tenant_name = $tenant_name;
					$tenant->ic_no = $ic_no;
					$tenant->passport_no = $passport_no;
					$tenant->status = $status;
					$tenant->gender = $gender;
					$tenant->type = $type;
					$tenant->rental_rate = $rental_rate;

					if ($marital_status == 'others') {
						$tenant->marital_status = $marital_status_text;
					} else {
						$tenant->marital_status = $marital_status;
					}

					$tenant->nationality = $nationality;
					$tenant->mailing_address = $mailing_address;

					if ($race == 'others') {
						$tenant->race = $race_text;
					} else {
						$tenant->race = $race;
					}

					$tenant->mobile = $mobile;
					$tenant->phone = $phone;
					$tenant->email = $email;
					$tenant->company_name = $company_name;
					$tenant->business_type = $business_type;
					$tenant->company_address = $company_address;
					$tenant->company_phone = $company_phone;
					$tenant->company_fax = $company_fax;
					$tenant->start_date = date('Y-m-d H:i:s');
					$tenant->property_id = $property->id;
					$tenant->created_by = Auth::id();

					if ($other_payment != 'none') {
						$tenant->other_payment = 1;
					}

					$tenant->save();

					// add to property history to save start date of tenant on this property id
					$history = new PropertyHistory;
					$history->tenant_id = $tenant->id;
					$history->property_id = $property->id;
					$history->save();

					// get last id in bill table
					$lastId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

					// save other payment in bill like MBPJ, LPHS and MBI
					if ($other_payment != 'none') {

						$bill = new Bill;
						$bill->bill_amount = $other_payment_amount;
						$bill->amount_due = $other_payment_amount;
						$bill->bill_no = Session::get('project')->location_code . '-' . (1000000 + $lastId);
						$bill->created_by = Auth::id();
						$bill->bill_type_id = $other_payment; // rental
						$bill->issue_date = date('Y-m-d H:i:s');
						$bill->tenant_id = $tenant->id;
						$bill->save();

						$lastId++;
					}

					// create current month rental bill
					$bill = new Bill;
					$bill->bill_amount = $rental_rate;
					$bill->amount_due = $rental_rate;
					$bill->bill_no = Session::get('project')->location_code . '-' . (1000000 + $lastId);
					$bill->created_by = Auth::id();
					$bill->bill_type_id = 1; // rental
					$bill->issue_date = date('Y-m') . '-01 00:00:00';
					$bill->tenant_id = $tenant->id;
					$bill->save();

					$transStatus = 'success';

					if ($tenant->email != '') {
						// send email
						$mail['name'] = $tenant->tenant_name;
						$mail['email'] = $tenant->email;
						$mail['subject'] = 'PHSSB: Pendaftaran Sebagai Penyewa';

						$data['name'] = $tenant->tenant_name;

						Mail::send('emails.welcome', $data, function ($message) use ($mail) {
							$message->to($mail['email'], $mail['name'])->subject($mail['subject']);
						});
					}

				} else {
					$transStatus = 'unit invalid';
				}
			});

			if ($transStatus === 'success') {
				// redirect to user routing with message
				return Redirect::to('tenant/create')->with('message', 'Tenant has been successfully registered.');
			} else if ($transStatus == 'unit invalid') {
				return Redirect::to('tenant/create')->with('error', 'Registration cannot be completed. The unit no is not valid or not available.')->withInput(Input::all());
			} else {
				return Redirect::to('tenant/create')->with('error', 'Problem occured. Registration cannot be completed.')->withInput(Input::all());
			}
		}
	}

	/**
	 * Display the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function show($id) {
		$data = array();
		$data['tenant'] = Tenant::select('tenants.id', 'tenants.tenant_name', 'ic_no', 'unit_no', 'tenants.status', 'passport_no', 'gender', 'race', 'marital_status', 'mobile', 'phone', 'company_name', 'company_address', 'business_type', 'email', 'nationality', 'mailing_address', 'start_date', 'company_fax', 'company_phone', 'start_date', 'other_payment', 'property_type', 'rental_rate', 'tenants.type')
			->join('properties', 'properties.id', '=', 'tenants.property_id')
			->where('tenants.id', $id)
			->first();

		// get list of rental history
		//AIN 20151210
		/*$data['rental_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name')
			->join('bills', 'bills.id', '=', 'payments.bill_id')
			->join('users', 'users.id', '=', 'payments.created_by')
			->where('bill_type_id', 1)
			->where('tenant_id', $id)
			->get();*/
		$data['rental_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name')
			->join('bills', 'bills.id', '=', 'payments.bill_id')
			->join('users', 'users.id', '=', 'payments.created_by')
			->where('bill_type_id', 1)
			->where('tenant_id', $id)
			->orderBy('payments.created_at','DESC')
			->get();

		// get list of water history
		//AIN 20151210
		$data['water_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name')
			->join('bills', 'bills.id', '=', 'payments.bill_id')
			->join('users', 'users.id', '=', 'payments.created_by')
			->where('bill_type_id', 2)
			->where('tenant_id', $id)
			->orderBy('payments.created_at','DESC')
			->get();
		/*data['water_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name')
			->join('bills', 'bills.id', '=', 'payments.bill_id')
			->join('users', 'users.id', '=', 'payments.created_by')
			->where('bill_type_id', 2)
			->where('tenant_id', $id)
			->orderBy('payments.created_at','DESC')
			->get();*/

		$data['deposit'] = Deposit::where('tenant_id', $id)->first();

		$data['currentRental'] = Bill::getCurrentRentalBillByTenantId($id);
		$data['totalOutstandingRental'] = Bill::getTotalRentalOutstandingByTenantId($id);
		$data['currentWater'] = Bill::getCurrentWaterBillByTenantId($id);
		$data['totalOutstandingWater'] = Bill::getTotalWaterOutstandingByTenantId($id);

		if ($data['tenant']->other_payment == 1) {
			// if have payment such as MBPJ, LPHS etc
			$data['otherPayment'] = Bill::join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
				->whereNotIn('bill_type_id', array(1, 2))
				->where('tenant_id', $id)
				->first();
			//AIN 20151210
			/*$data['other_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name', 'optional_bill_date')
				->join('bills', 'bills.id', '=', 'payments.bill_id')
				->join('users', 'users.id', '=', 'payments.created_by')
				->whereNotIn('bill_type_id', array(1, 2))
				->where('tenant_id', $id)
				->get();*/
			$data['other_payments_history'] = Payment::select('payments.id', 'payments.created_at as payment_date', 'amount_paid', 'receipt_no', 'bills.issue_date as bill_date', 'name', 'optional_bill_date')
				->join('bills', 'bills.id', '=', 'payments.bill_id')
				->join('users', 'users.id', '=', 'payments.created_by')
				->whereNotIn('bill_type_id', array(1, 2))
				->where('tenant_id', $id)
				->orderBy('payments.created_at','DESC')
				->get();
		}

		$data['project'] = Location::find(Session::get('project')->location_id);

		$data['scripts'] = array('date-mon-year.js', 'deposit.js');
		return View::make('tenant.details', $data);
	}

	/**
	 * Show the form for editing the specified resource.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function edit($id) {
		$data = array();
		$tenant = Tenant::where('tenants.id', $id)
			->first();

		$tenant->id = $id;

		if ($tenant->marital_status != 'single' && $tenant->marital_status != 'married') {
			$tenant->marital_status_text = $tenant->marital_status;
			$tenant->marital_status = 'others';
		}

		if (!in_array($tenant->race, array('malay', 'chinese', 'indian'))) {
			$tenant->race_text = $tenant->race;
			$tenant->race = 'others';
		}

		$data['scripts'] = array('select-unit.js');
		$data['tenant'] = $tenant;
		$data['availableUnitsOptions'] = Property::getAvailableUnitOptions();

		return View::make('tenant.form', $data);
	}

	/**
	 * Update the specified resource in storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function update($id) {

		// validate post fields
		/*
		$rules = array(
			'ic_no' => 'required|numeric|unique:tenants,ic_no,' . $id,
			'tenant_name' => 'required|unique:tenants,tenant_name,' . $id,
			'status' => 'required',
			'gender' => 'required',
			'rental_rate' => 'required|numeric',
			'marital_status' => 'required',
			'nationality' => 'required',
			'mailing_address' => 'required',
			'email' => 'email|unique:tenants,email,' . $id,
			'race' => 'required',
			'mobile' => 'required|numeric|unique:tenants,mobile,' . $id,
			'phone' => 'numeric',
			'company_fax' => 'numeric',
			'company_phone' => 'numeric',
			'mailing_address' => 'required',
		);
		*/
		$rules = array(
			'ic_no' => 'required|numeric|unique:tenants,ic_no,' . $id,
			'tenant_name' => 'required',
			'status' => 'required',
			'gender' => 'required',
			'rental_rate' => 'required|numeric',
			'marital_status' => 'required',
			'nationality' => 'required',
			'mailing_address' => 'required',
			'email' => 'email|unique:tenants,email,' . $id,
			'race' => 'required',
			'mobile' => 'required',
			'mailing_address' => 'required',
		);

		$validator = Validator::make(Input::all(), $rules);

		// process the add
		if ($validator->fails()) {
			return Redirect::route('tenant.edit', $id)
				->withErrors($validator)
				->withInput(Input::all());
		} else {

			// get input
			$tenant_name = Input::get('tenant_name');
			$ic_no = Input::get('ic_no');
			$unit_no = Input::get('unit_no');
			$passport_no = Input::get('passport_no');
			$status = Input::get('status');
			$gender = Input::get('gender');
			$type = Input::get('type');
			$rental_rate = Input::get('rental_rate');
			$marital_status = Input::get('marital_status');
			$marital_status_text = Input::get('marital_status_text');
			$nationality = Input::get('nationality');
			$mailing_address = Input::get('mailing_address');
			$race = Input::get('race');
			$race_text = Input::get('race_text');
			$mobile = Input::get('mobile');
			$phone = Input::get('phone');
			$email = Input::get('email');
			$company_name = Input::get('company_name');
			$business_type = Input::get('business_type');
			$company_address = Input::get('company_address');
			$company_phone = Input::get('company_phone');
			$company_fax = Input::get('company_fax');

			$tenant = Tenant::find($id);
			$property = Property::find($tenant->property_id);

			if ($property) {

				//  update tenant with inputs
				$tenant->tenant_name = $tenant_name;
				$tenant->ic_no = $ic_no;
				$tenant->passport_no = $passport_no;
				$tenant->status = $status;
				$tenant->gender = $gender;
				$tenant->type = $type;
				$tenant->rental_rate = $rental_rate;

				if ($marital_status === 'others') {
					$tenant->marital_status = $marital_status_text;
				} else {
					$tenant->marital_status = $marital_status;
				}

				$tenant->nationality = $nationality;
				$tenant->mailing_address = $mailing_address;

				if ($race === 'others') {
					$tenant->race = $race_text;
				} else {
					$tenant->race = $race;
				}

				$tenant->mobile = $mobile;
				$tenant->phone = $phone;
				$tenant->email = $email;
				$tenant->company_name = $company_name;
				$tenant->business_type = $business_type;
				$tenant->company_address = $company_address;
				$tenant->company_phone = $company_phone;
				$tenant->company_fax = $company_fax;
				$tenant->property_id = $property->id;
				$tenant->created_by = Auth::id();
				$tenant->save();

				//check status tenant active or inactive
				// if inactive make property vacancy available
				if($status === 'disable'){
					$property = Property::find($tenant->property_id);
					$property->vacancy = 'available';
					$property->status = 'enable';
					$property->save();
				}
				// if active make property vacancy unavailable
				else if($status === 'enable'){
					$property = Property::find($tenant->property_id);
					$property->vacancy = 'unavailable';
					$property->status = 'disable';
					$property->save();
				}
				
				
				
				// redirect to user routing with message
				return Redirect::to('tenant/' . $id . '/edit')->with('message', 'Tenant has been successfully updated.');
			} else {
				return Redirect::to('tenant/' . $id . '/edit')->with('error', 'Registration cannot be completed. The unit no ' . $unit_no . ' is not valid.');
			}
		}
	}

	/**
	 * Remove the specified resource from storage.
	 *
	 * @param  int  $id
	 * @return Response
	 */
	public function destroy($id) {
		$tenant = Tenant::find($id);
		$tenant->delete();
	}

	public function postTenantStatus($id) {
		// disable or enable tenant
		$tenant = Tenant::find($id);
		if ($tenant->status == 'disable') {
			$tenant->status = 'enable';
		} else {
			$tenant->status = 'disable';
			$history = PropertyHistory::where('tenant_id', $id)->orderBy('created_at', 'DESC')->first();
			if ($history) {
				$history->status = 'left';
				$history->save();
			}
		}

		$tenant->save();

		// make property vacancy available
		$property = Property::find($tenant->property_id);
		$property->vacancy = 'available';
		$property->status = 'enable';
		$property->save();
	}

	public function submitDeposit() {
		// validate post fields
		$rules = array(
			'two_month_rental' => 'required|numeric',
			'one_month_rental' => 'required|numeric',
			'utilities' => 'required|numeric',
			'management_fee' => 'required|numeric',
			'mon_year' => 'required',
		);

		$validator = Validator::make(Input::all(), $rules);

		// process the add
		if ($validator->fails()) {
			return Response::json(array('status' => 'error', 'message' => $validator));
		} else {
			DB::beginTransaction();

			try {
				// get input
				$description = Input::get('description');
				$two_month_rental = Input::get('two_month_rental');
				$one_month_rental = Input::get('one_month_rental');
				$mon_year = Input::get('mon_year');
				$utilities = Input::get('utilities');
				$management_fee = Input::get('management_fee');
				$note = Input::get('note');
				$tenant_id = Input::get('tenant_id');

				$locationCode = Session::get('project')->location_code;

				$lastDepositId = Deposit::orderBy('id', 'DESC')->pluck('id') ? Deposit::orderBy('id', 'DESC')->pluck('id') + 1 : 1;

				//ain 20160603 start
				$code = 'D';
				$receiptNumberSQL = ReceiptNumber::where('location_code',$locationCode)
						->where('payment_type',$code)
						->orderBy('running_no','DESC')
						->pluck('running_no');
				$d = $receiptNumberSQL + 1;
				//ain 20160603 end
				
				$deposit = new Deposit;
				$deposit->tenant_id = $tenant_id;
				$deposit->created_by = Auth::id();
				//ain 20160603 start
				//$deposit->receipt_no = $locationCode . '-' . (10000000 + $lastDepositId);
				$deposit->receipt_no = $code . '-' . (20000000 + $d);
				//ain 20160603 end
				$deposit->utilities = $utilities;
				$deposit->management_fee = $management_fee;
				$deposit->note = $note;
				$deposit->description = $description;
				$deposit->one_month_rental = $one_month_rental;
				$deposit->one_month_date = $mon_year;
				$deposit->two_month_rental = $two_month_rental;
				$deposit->total_deposit = $two_month_rental + $one_month_rental + $management_fee + $utilities;
				$deposit->save();
				
				//ain 20160929 start
				$receiptNumber = new ReceiptNumber;
				$receiptNumber->location_code = $locationCode;
				$receiptNumber->bill_type_id = 6;
				$receiptNumber->payment_type = $code;
				$receiptNumber->running_no = $d;
				$receiptNumber->serial_no = 20000000 + $d;
				$receiptNumber->save();
				//ain 20160929 end
				
				
				// get tenant
				$tenant = Tenant::join('properties', 'properties.id', '=', 'tenants.property_id')
					->where('tenants.id', $tenant_id)->first();

				// create bill and payment for one month
				$lastBillId = Bill::orderBy('id', 'DESC')->pluck('id') ? Bill::orderBy('id', 'DESC')->pluck('id') + 1 : 1;
				$bill = Bill::where('issue_date', date('Y-m', strtotime($mon_year)) . '-01 00:00:00')
					->where('tenant_id', $tenant_id)
					->first();

				if (!$bill) {
					$bill = new Bill;
					$bill->bill_no = $locationCode . '-' . (1000000 + $lastBillId);
					$bill->bill_amount = $tenant->rental_rate;
					$bill->amount_due = 0;
					$bill->payment_status = 'paid';
					$bill->bill_type_id = 1; // rental type
					$bill->created_by = Auth::id();
					$bill->tenant_id = $tenant_id;
					$bill->issue_date = date('Y-m', strtotime($mon_year)) . '-01 00:00:00';
					$bill->save();
				} else {
					$bill->amount_due = 0;
					$bill->payment_status = 'paid';
					$bill->save();
				}

				$lastPaymentId = Payment::orderBy('id', 'DESC')->pluck('id') ? Payment::orderBy('id', 'DESC')->pluck('id') + 1 : 1;
				//Ain 20160905
				//problem,resit xperlu create,hanya create bill
				/*
				$oneMonthPayment = new Payment;
				$oneMonthPayment->created_by = Auth::id();
				$oneMonthPayment->amount_paid = $bill->bill_amount;
				$oneMonthPayment->bill_id = $bill->id;
				$oneMonthPayment->receipt_no = $locationCode . '-' . (1000000 + $lastPaymentId);
				$oneMonthPayment->save();
				*/
				DB::commit();

				return Response::json(array('status' => 'ok'));
			} catch (Exception $e) {
				DB::rollback();
				return Response::json(array('status' => 'error', 'message' => $e->getMessage()));
			}
		}
	}

	function search() {
		$inputs = Input::all();
		unset($inputs['_token']);

		if (Input::has('block')) {
			$block = implode(',', $inputs['block']);
			$inputs['block'] = $block;
		}

		return Redirect::action('TenantController@index', $inputs);
	}

	function noticeHistory($id) {
		$data = array();
		$data['id'] = $id;
		$data['histories'] = NoticeHistory::where('tenant_id', $id)->get();

		return View::make('tenant.notice_history', $data);
	}

}
