<?php

class Bill extends Eloquent {

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'bills';
    protected $fillable = ['bill_no', 'type', 'amount_due', 'payment_status'];

    public static function getCurrentRentalBillByTenantId($id) {
	$currRentalBill = Bill::select('bills.id', 'bills.issue_date', 'payment_status', 'bill_type_name as bill_type', 'bill_amount', 'amount_due')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->where('tenant_id', $id)
		->where('bill_type_name', 'rental')
		->where('issue_date', date('Y-m') . '-01')
		->first();
	
	return $currRentalBill;
    }
    
    public static function getCurrentWaterBillByTenantId($id) {
	$currWaterBill = Bill::select('bills.id', 'bills.issue_date', 'payment_status', 'bill_type_name as bill_type', 'amount_due', 'bill_amount')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->where('tenant_id', $id)
		->where('bill_type_name', 'water')
		->where('issue_date', date('Y-m') . '-01')
		->first();
	
	return $currWaterBill;
    }
    
    public static function getOutstandingRentalBillsByTenantId($id) {
	
	$outstandingRentalBills = Bill::select('bills.id', 'bills.issue_date', 'payment_status', 'bill_type_name as bill_type', 'amount_due')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->where('tenant_id', $id)
		->where('bill_type_name', 'rental')
//		->where('bills.id', '<>', $currRentalBill->id)
		->where('issue_date', '<', date('Y-m') . '-01')
		->where('payment_status', '<>', 'paid')
		->get();
	
	return $outstandingRentalBills;
    }
    
    public static function getOutstandingWaterBillsByTenantId($id) {
	
	$outstandingWaterBills = Bill::select('bills.id', 'bills.issue_date', 'payment_status', 'bill_type_name as bill_type', 'amount_due')
		->join('bill_types', 'bill_types.id', '=', 'bills.bill_type_id')
		->where('tenant_id', $id)
		->where('bill_type_name', 'water')
//		->where('bills.id', '<>', $currWaterBill->id)
		->where('issue_date', '<', date('Y-m') . '-01')
		->where('payment_status', '<>', 'paid')
		->get();
	
	return $outstandingWaterBills;
	
    }
    
    public static function getTotalRentalOutstandingByTenantId($id) {
	$outstandingBills = Bill::getOutstandingRentalBillsByTenantId($id);
	
	$sum = 0;
	foreach ($outstandingBills as $bill) {
	    $sum += $bill->amount_due;
	}
	
	return $sum;
    }
    
    public static function getTotalWaterOutstandingByTenantId($id) {
	$outstandingBills = Bill::getOutstandingWaterBillsByTenantId($id);
	
	$sum = 0;
	foreach ($outstandingBills as $bill) {
	    $sum += $bill->amount_due;
	}
	
	return $sum;
    }
}
