<?php

class Payment extends Eloquent {

    /**
     * The database table used by the model.
     *
     * @var string
     */
    protected $table = 'payments';
    protected $fillable = ['amount_paid', 'receipt_no'];

    public static function getTodayOutstandingCollection() {
	$payments = Payment::join('bills', 'bills.id', '=', 'payments.bill_id');

	if (Session::get('project')->location_name != 'PHSSB') {
	    $payments = $payments->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
	    ->join('properties', 'properties.id', '=', 'tenants.property_id')
	    ->where('properties.location_id', Session::get('project')->location_id);
	}
	
	$payments = $payments->where('bills.issue_date', '<', date('Y-m-') . '01 00:00:00')
		->where('payments.created_at', 'LIKE', date('Y-m-d') . '%');

	return $payments;
    }

    public static function getTodayCollection() {
	$payments = Payment::join('bills', 'bills.id', '=', 'payments.bill_id');

	if (Session::get('project')->location_name != 'PHSSB') {
	    $payments = $payments->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
	    ->join('properties', 'properties.id', '=', 'tenants.property_id')
	    ->where('properties.location_id', Session::get('project')->location_id);
	}
	
	$payments = $payments->where('bills.issue_date', '>=', date('Y-m-') . '01 00:00:00')
		->where('payments.created_at', 'LIKE', date('Y-m-d') . '%');

	return $payments;
    }

    public static function getThisMonthCollection() {
	$start = date('Y-m') . '-1';
	$end = date('Y-m-d', strtotime("+1 months", strtotime($start)) - 3600);
	$payments = Payment::join('bills', 'bills.id', '=', 'payments.bill_id');

	if (Session::get('project')->location_name != 'PHSSB') {
	    $payments = $payments->join('tenants', 'tenants.id', '=', 'bills.tenant_id')
	    ->join('properties', 'properties.id', '=', 'tenants.property_id')
	    ->where('properties.location_id', Session::get('project')->location_id);
	}
	
	$payments = $payments->whereBetween('payments.created_at', array($start, $end));

	return $payments;
    }

}
