<?php

/*
  |--------------------------------------------------------------------------
  | Application Routes
  |--------------------------------------------------------------------------
  |
  | Here is where you can register all of the routes for an application.
  | It's a breeze. Simply tell Laravel the URIs it should respond to
  | and give it the Closure to execute when that URI is requested.
  |
 */

Route::get('/', function() {
    if (Auth::check()) {
	return Redirect::to('dashboard');
    } else {
	return Redirect::to('login');
    }
});

Route::get('password/remind', 'RemindersController@getRemind');
Route::post('password/remind', 'RemindersController@postRemind');
Route::get('password/reset/{token}', 'RemindersController@getReset');
Route::post('password/reset/{token}', 'RemindersController@postReset');
// Auth
Route::get('login', 'AuthController@index');
Route::post('login', array('before' => 'csrf', 'uses' => 'AuthController@submitLogin'));

Route::get('logout', function() {
    Auth::logout();
    return Redirect::to('/');
});

Route::group(array('before' => 'auth'), function() {
    // Dashboard
    Route::get('dashboard', 'DashboardController@index');
    Route::get('dashboard/summary', 'DashboardController@summary');
    Route::resource('bill', 'BillController');
    Route::get('notpaid', 'BillController@notPaidList');
    Route::post('notpaid/filter', 'BillController@filterNotPaidList');
    Route::get('notice/{option}', 'BillController@getNotice');
    Route::resource('payment', 'PaymentController');
    Route::post('payment/search', 'PaymentController@search');
    Route::post('payment/preview', 'PaymentController@submitPaymentPreview');
    Route::post('payment/submit', 'PaymentController@submitPayment');
    Route::post('payment/check', 'PaymentController@checkPayment');
    Route::get('print/receipt', 'PaymentController@printPayment');
    Route::post('deposit/submit', 'TenantController@submitDeposit');
    Route::get('report', 'ReportController@index');
    Route::post('report/filter', 'ReportController@submitFilter');
    Route::get('report/analysis', 'ReportController@dataAnalysis');

    Route::resource('applicant', 'ApplicantController');
    Route::post('applicant/status/update', 'ApplicantController@changeApplicantStatus');
    Route::resource('tenant', 'TenantController');
    Route::post('tenant/search', 'TenantController@search');
    Route::post('tenant/status/{id?}', 'TenantController@postTenantStatus');
    Route::get('tenant/history/{id?}', 'TenantController@noticeHistory');

    Route::get('admin/switch/{id}', 'AuthController@switchAdminLocation');
    Route::resource('profile', 'UserController',
                array('only' => array('edit', 'update')));

    Route::group(array('before' => 'admin'), function() {
    	Route::resource('user', 'UserController');
    	Route::get('user/assign/{id}', 'UserController@assignLocation');
    	Route::post('user/assign/{id}', 'UserController@submitAssignLocation');
    	Route::resource('project', 'ProjectController');
    	Route::resource('location', 'LocationController');
    	Route::resource('property', 'PropertyController');
    	Route::get('property/history/{id}', 'PropertyController@getHistory');
    	Route::resource('note', 'NoteController');
    	Route::post('property/check', 'PropertyController@check');
    	Route::get('log/cron', 'LogController@cron');
    });
});
